import itertools
import random

from mud.data import player, skills1, m1,m2,m3
from mud.services import init_monster, initmap, move, checkhit

# map=initmap()
# x=init_monster(map,)
# for i in range(50):
#     print(x[i])
# postion = random.sample(list(itertools.product(range(10), range(10))), 50)
# print(postion)
# mx={'x,y':(0,0)}
# ms=[]
# for i in range(50):
#     print(postion[i])
#     mx = {'x,y': (0, 0)}
#     mx['x,y']=postion[i]
#     ms.append(mx)
# # print(ms)
# from mud.view import display_battle
# player={'id':0,'name':'','hp':100,'mp':50,'damage':10,'defence':8,'x,y':(0,0),'skills':{}}
# postion = random.sample(list(itertools.product(range(10), range(10))), 50)
# while True:
#     positions=input('输入指令')
#     player=move(player,positions)
#     print(player['x,y'])
#     print(postion)
#     flag=checkhit(player)
#     if flag==True:
#         display_battle()
from mud.view import display_play, display_game
# player['skills']=skills1
# print(player['skills']['mp'])
# postion = random.sample(list(itertools.product(range(10), range(10))),50)
# m=[eval('m'+str(i+1))for i in range(3)]
# print(m)
# print(m)
# for i in range(50):
#     mx = random.choice(m)
#     mx['x,y']=(0,0)
#     mx['x,y']= postion[i]
#     mx['item'] = random.choice(item)
#     mx=mx
#     ms.append(mx)
with open('user.txt', 'r', encoding='utf-8') as f:
    users = f.readlines()
    for usre in users:
        usre.replace('\n','')
        print(usre)
    # for user in users:
    #     user = eval(str(user)-'\n')
    #     print(user)


import time

from ATM.action.login_page import Page_login
from ATM.comon.common import Dr_get


class Logintest:
    def __init__(self):
        self.dr=Page_login()
    def test_login(self,user,pwd,expect):
        self.dr.do_login(user,pwd)
        try:
            # self.dr.switch_get()
            time.sleep(1)
            self.dr.alert_get().click()
        finally:
            erro=0
            if expect=='失败':
                if '销售出库' not in self.dr.titie():
                    result='成功'
                else:
                    result='失败'
                    Dr_get.imagne()
                    erro=1
            else:
                if '销售出库'  in self.dr.titie():
                    result = '成功'
                else:
                    result = '失败'
                    Dr_get.imagne()
                    erro = 1
            return result,erro

    def main_login(self):
        l = Dr_get.data_get('D:\python test\ATM\data\login.csv')
        # print(l)
        for i in l[1:]:
            li=i.split(',')
            r, e = self.test_login(li[0], li[1], li[-1].strip())
            time.sleep(1)
            print(r, e)







import glob
import os
import time


class App_t:
    def __init__(self):
        self.page_list=glob.glob(r"D:/测试/app"+"/*.apk")
        self.datas=self.data()

    def get_photo(self,p):
        path = time.strftime(f'{p}-%H%M%S.png')
        os.system(f'adb shell screencap -p /sdcard/{path}')
        os.system(f'adb pull /sdcard/{path} D:\测试\\app\新建文件夹 (2)\\{path}')

    def data(self):
        data=[]
        for i in self.page_list:
            dic = {}
            r=os.popen(f'D:\sdk\\build-tools\\29.0.3\\aapt2 dump badging {i} |findstr package')
            r1=r.buffer.read().decode('unicode-escape')
            bag=r1.split(' ')[1].split('=')[1]
            r2 = os.popen(f'D:\sdk\\build-tools\\29.0.3\\aapt2 dump badging {i} |findstr launchable-activity')
            r3 = r2.buffer.read().decode('unicode-escape')
            act=r3.split(' ')[1].split('=')[1]
            dic['package']=bag.strip('\'')
            dic['Activity']=act.strip('\'')
            data.append(dic)
        return data


    def install(self):
        for i in self.page_list:
            try:
                r=os.popen(f'adb install -r {i}').read()
            except Exception as e:
                print(e)
            finally:
                pg=i[17:]
                # r=os.popen('adb shell pm list package -3').read()
                # print(r)
                if r=='':
                    print(f'{pg}安装过程成功')
                else:
                    print(f'{pg}安装过程失败')
                    self.get_photo(pg)
                time.sleep(2)

    def start(self):
        for i in self.datas:
            p=i['package']
            a=i['Activity']
            try:
                r=os.popen(f'adb shell am start -W -n {p}/{a}|findstr Status').read()
                r1 = os.popen(f'adb shell am start -W -n {p}/{a} |findstr WaitTime').read()
            except Exception as e:
                print(e)
            finally:
                t=r1.strip().split(':')[1]
                t1=r.strip().split(':')[1].strip()
                if t1=='ok':
                    print(f'{p}启动成功，启动时间为{t}')
                else:
                    print(f'{p}启动异常，启动时间为{t}')
                    self.get_photo(p)


    def text(self):
        for i in self.datas:
            p=i['package']
            a=i['Activity']
            log_path = time.strftime(f'{p}-%H%M%S.txt')
            os.system(f'adb shell monkey -p {p} -v -v --throttle 50 1000 > D:\\{log_path}')
            time.sleep(8)
            with open(f'D:\\{log_path}') as f:
                result = f.read()
            if 'anr' in result or 'ANR' in result:
                print(f'此次{p}应用执行monkey测试时出现了无响应，响应超时异常!')
                self.get_photo(p)
            else:
                print(f'此次{p}应用执行monkey测试时未出现无响应，响应超时异常.')
            if 'crash' in result or 'CRASH' in result:
                print(f'此次{p}应用执行monkey测试时出现了崩溃，闪退异常!')
                self.get_photo(p)
            else:
                print(f'此次{p}应用执行monkey测试时未出现崩溃，闪退异常.')
            if 'error' in result or 'EXCEPTION' in result:
                print(f'此次{p}应用执行monkey测试时出现了未知异常!')
                self.get_photo(p)
            if 'Monkey finished' in result:
                print(f'此次{p}应用在执行monkey测试时未出现任何异常.')

    def close(self):
        for i in self.datas:
            p=i['package']
            a=i['Activity']
            try:
                os.system(f'adb shell am force-stop {p}')
                time.sleep(1)
                r=os.popen(f'adb shell ps |findstr {p}').read()
            except Exception as e:
                print(e)
            # print(r)
            if not r:
                print(f'{p}关闭成功')
            else:
                print(f'{p}关闭异常')
                self.get_photo(p)

    def uninstall(self):
        for i in self.datas:
            p=i['package']
            # print(p)
            a=i['Activity']
            try:
                os.system(f'adb uninstall {p}')
                time.sleep(1)
                r=os.popen('adb shell pm list package -3').read()
            except Exception as e:
                print(e)
            if p not in r:
                print(f'{p}卸载成功')
            else:
                print(f'{p}卸载失败')
                self.get_photo(p)


    def main(self):
        s=input('输入测试类型')
        if s=='monkey':
            self.install()
            self.text()
            self.uninstall()
        else:
            self.install()
            self.start()
            self.close()
            self.uninstall()




if __name__ == '__main__':
    a=App_t().main()




# #coding=utf-8
# user=['admin''0000']
# flag=False
# #1.会员注册
# name = input('输入昵称')
# password = input('输入密码')
# checkword = input('确认密码')
# if 8<=len(name)<=20  and name.isalnum()==True and 6<=len(password)<=12 and checkword==password:
#     print('注册成功')
#     user.append(name)
#     user.append(password)
# else:
#     print('注册失败')
#     quit()
# #用户登录
# username=input('输入用户名')
# passwod=input('密码')
# i=1
# for n in range(5):
#     if username in user and passwod in user:
#         print('登录成功')
#         flag=True
#         break
#     else:
#         print('登录失败')
#         i=i+1
#         username = input('输入用户名')
#         passwod = input('密码')
#         if i==5:
#             print('账户已锁')
#             username = input('输入管理员用户名')
#             passwod = input('管理员密码')
#             if username=='admin' and passwod == '0000':
#                 print('登陆成功')
#                 i=1
#                 continue
#进入游戏
import random
import sys

map_width=10
map_high=10
map_master=[]
master1={'name':'公鸡','hp':100,'attack':10,'armor':5,'item':'剑'}
master2={'name':'猪','hp':100,'attack':10,'armor':5,'item':'盾'}
master3={'name':'野狗','hp':100,'attack':10,'armor':5,'item':'霜之哀伤'}
master4={'name':'稻草人','hp':100,'attack':10,'armor':5,'item':'反甲'}
masters=[master1,master2,master3,master4]
hp_man=0
hp_master=0
for a in range(50):
    x=random.randint(0,map_width-1)
    y=random.randint(0,map_high-1)
    map_master.append((x,y))
man_high=5
man_weigth=5
man={'hp':200,'mp':100,'attack':10,'armor':5}
kill=('普通攻击','kill1','kill2','kill3')
#普通攻击--》hp-10 kill1--》hp-20 kill2--》hp-30 kill3--》hp-30
item=()
print(man)
while True:
    #操作方向
    postion=input('输入')
    if postion=='w':
        man_high+=1
    if postion=='s':
        man_high-=1
    if postion=='a':
        man_weigth+=1
    if postion=='d':
        man_weigth-=1
    print(man_high,man_weigth)
    #战斗
    if (man_high,man_weigth) in map_master:
        print('进行战斗')
        for i in range(1):
            master = random.choice(masters)
            hp_man = man['hp'] + man['armor']
            hp_master = master['hp'] + master['armor']
            while hp_man>0:
                print('*'*5,'1.普通攻击','2.kill1','3.kill2','4.kill3','*'*5)
                skill=input('输入攻击方式')
                if skill=='1':
                    hp_master=hp_master-20
                    hp_man = hp_man-5
                elif skill=='2':
                    hp_master=hp_master-30
                    hp_man = hp_man-5
                elif skill=='3':
                    hp_master=hp_master-40
                    hp_man = hp_man- 5
                elif skill=='4':
                    hp_master=hp_master-50
                    hp_man = hp_man- 5
                print(hp_man,master)
                print(hp_master)
                if hp_master <= 0:
                    print('真不挫')
                    break
                if hp_man <= 0:
                    print('游戏结束')
                    sys.exit(0)









# while flag==True:
# print(x1map,y1map)
# for b in xmap:
#     for c in ymap:
#         if b == 10:
#             print('*' * b)














#进入游戏



from ATM.comon.common import Dr_get


class Page_customer:
    def __init__(self):
        self.dr=Dr_get.get_dr()
    def link_customer(self):
        return self.dr.find_element_by_link_text('会员管理')
    def input_phone(self):
        return self.dr.find_element_by_id('customerphone')
    def buton_new(self):
        return self.dr.find_element_by_xpath('/html/body/div[4]/div[1]/form[2]/div[2]/button[1]')
    def close(self):
        return self.dr.close()
    def do_customer_add(self,phone):
        self.link_customer().click()
        self.input_phone().send_keys(phone)
        self.buton_new().click()


import os
import subprocess
import time

#coding=utf8
from appium import webdriver
class Com():
    def __init__(self):
        self.app1 = {
            "platformName": "Android",
            "appPackage": "com.modernsky.istv",
            "appActivity": "com.modernsky.istv.ui.activity.MainActivity",
            "noReset": "False"}
        self.app1["deviceName"]='127.0.0.1:62001'
        self.app1["platformVersion"]='7.1.2'
        self.app1["udid"] = '127.0.0.1:62001'
        os.system('taskkill /f /im node.exe')
        time.sleep(1)
        subprocess.Popen(f'start /b C:/Users/树先生/AppData/Roaming/npm/appium.cmd -a 127.0.0.1 -p 4723 -bp 6000 -U 127.0.0.1:62001 --platform-version 7.1.2',
            shell=True)
        time.sleep(4)
        self.dr = webdriver.Remote('http://127.0.0.1:4723/wd/hub', self.app1)
        self.start()
    def start(self):
        os.system(' adb shell am start -W -n  com.modernsky.istv/com.modernsky.istv.ui.activity.MainActivity')


if __name__ == '__main__':
    os.system('taskkill /f /im appium')
    c=Com()



from ATM.comon.common import Dr_get


class Page_login:
    def __init__(self):
        self.dr=Dr_get.get_dr()
    def input_user(self):
        return self.dr.find_element_by_id('username')
    def input_pad(self):
        return self.dr.find_element_by_id('password')
    def input_verfiy(self):
        return self.dr.find_element_by_id('verifycode')
    def buttun_login(self):
        return self.dr.find_element_by_xpath('/html/body/div[4]/div/form/div[6]/button')
    def titie(self):
        return self.dr.title
    def close(self):
        return self.dr.close()
    def alert_get(self):
        return self.dr.find_element_by_xpath('/html/body/div[6]/div/div/div[3]/button')
    def do_login(self,user,pwd):
        self.input_user().clear()
        self.input_user().send_keys(user)
        self.input_pad().clear()
        self.input_pad().send_keys(pwd)
        self.input_verfiy().clear()
        self.input_verfiy().send_keys('0000')
        self.buttun_login().click()


#cording=utf8
import requests,pytest
url='http://127.0.0.1/?user/loginSubmit'
p={'name':'admin','password':'Zz123456','isAjax':'1','getToken':'1'}
r=requests.get(url=url,params=p).json()  #获取accessToken

# url='http://127.0.0.1/?explorer/pathList'
# p1={'accessToken':r['data']}
# r1=requests.post(url,p1)
# # print(r1.json())
#
# url='http://127.0.0.1/?explorer/pathInfo'
# p2={'dataArr':[{"type":"file","path":"D:/xampp/htdocs/data/User/admin/home/音乐/"}],'accessToken':r['data']}
# r2=requests.post(url,p2)
# # print(r2.json())

data=([r['data'],'D:/xampp/htdocs/data/User/admin/home/desktop/myfolder','True'],[r['data'],'','False'])
@pytest.mark.parametrize('info',data)
def test_mkdir(info):#新建文件夹接口测试
    url='http://127.0.0.1/?explorer/mkdir'
    p3={'accessToken':info[0],'path':info[1]}
    r3=requests.post(url,p3).json()
    assert info[-1]==str(r3['code'])

if __name__ == '__main__':
    pytest.main(['-v',__file__])


import os

from woniuticket.coomon.common import get_data, get_dic, request_t
import pytest
case=get_data(7)
@pytest.mark.parametrize('info',case['data'])
def test_main(info):
    data=get_dic(info[1])
    url=case['url']
    code=info[2]
    message=info[3]
    method=case['method']
    r=request_t(m=method,url=url,data=data)
    print(r.json())
    assert code in r.json()['code']
    assert message in r.json()['message']
case=get_data(0)
@pytest.mark.parametrize('info',case['data'])
def test_main1(info):
    data=get_dic(info[1])
    url=case['url']
    print(url)
    code=info[2]
    message=info[3]
    method=case['method']
    r=request_t(m=method,url=url,data=data)
    print(r.json())
    assert code in r.json()['code']
    assert message in r.json()['message']

if __name__ == '__main__':
    pytest.main(['-v','--alluredir=../report/',__file__])
    # os.system('D:\\Programs\\allure-commandline-2.8.1\\allure-2.8.1\\bin\\allure.bat generate "D:\\python test\\woniuticket\\report" -o "D:\\python test\\woniuticket\\report\\alreport" ')




#cording=utf-8
import xlrd
class Date:
    def __init__(self,excelname):
        self.filename=excelname
        self.book=xlrd.open_workbook(self.filename)
    def get_data(self,sheetname):
        sheet=self.book.sheet_by_name(sheetname)
        cols=sheet.ncols
        rows=sheet.nrows
        datacow=[]
        datacols=[]
        for i in range(rows) :
            datacow.append(sheet.row_values(i))
            print(sheet.row_values(i))
        # for i in range(cols):
        #     datacols.append(sheet.col_values(i))
        #     print(sheet.col_values(i))
        return datacow
    def get_dict(self,data):
        head=data[0]
        data=data[1:]
        items=[]
        for i in data:
            temp = {}
            temp[head[0]] = int(i[0])
            temp[head[1]] = i[1]
            temp[head[2]] = int(i[2])
            temp[head[3]] = int(i[3])
        items.append(temp)
        return items




if __name__=='__main__':
    datas=Date('data.xls')
    da=datas.get_data('sheet1')
    dat=datas.get_dict(da)
    print(dat)
    items1={'id':1,'name':'菜刀','type':1,'value':3}
    b=items1.items()
    print(b)


from POM.common import Dr_get
class Page_login:
    def __init__(self):
        self.dr=Dr_get.get_dr()
    def input_user(self):
        return self.dr.find_element_by_id('username')
    def input_pad(self):
        return self.dr.find_element_by_id('password')
    def input_verfiy(self):
        return self.dr.find_element_by_id('verifycode')
    def buttun_login(self):
        return self.dr.find_element_by_xpath('/html/body/div[4]/div/form/div[6]/button')


import time

import cv2
from PIL import ImageGrab
import os

from appium import webdriver

from appium_img.aada import pos, pos2


class Img_mai:
    def __init__(self):
        # self.app1 = {
        #     "platformName": "Android",
        #     "appPackage": "com.miui.calculator",
        #     "appActivity": "com.miui.calculator.cal.CalculatorActivity",
        #     "noReset":"True"
        #     }
        # self.app1["deviceName"]="appium"
        # self.app1["platformVersion"]="7.1.2"
        # self.app1["udid"]="127.0.0.1:62001"
        # self.d=webdriver.Remote('http://127.0.0.1:4723/wd/hub',self.app1)
        self.path=os.path.abspath('./imgs')
    def return_pos(self,name):
        # print(self.path+'/big.png')
        # self.d.save_screenshot('D:\python test\\appium_img\imgs\\big.jpg')
        os.system('adb shell screencap  -p /sdcard/big.jpg')
        os.system('adb pull /sdcard/big.jpg "D:\python test\\appium_img\imgs"')
        s=cv2.imread(self.path+f'\\{name}')
        b=cv2.imread('D:\python test\\appium_img\imgs\\big.jpg')
        result=cv2.matchTemplate(b,s,cv2.TM_CCOEFF_NORMED)
        # print(result)
        pos=cv2.minMaxLoc(result)
        # print(pos)
        x=pos[3][0] + int(s.shape[1]/2)
        y=pos[3][1] + int(s.shape[0]/2)
        if pos[1]>0.8:
            # print(x,y)
            return x,y
        else:
            return -1,-1
    def click(self,n):
        x,y=self.return_pos(n)
        self.d.tap([(x,y)],10)

    def start(self,p):
        os.system(f'adb shell am start -W -n {p}/com.miui.calculator.cal.CalculatorActivity')

    def click2(self,n):
        # x,y=self.return_pos(n)
        x,y=pos(n)
        os.system(f'adb shell input tap {x} {y}')
    def click3(self,n):
        x,y=pos2(n)
        os.system(f'adb shell input tap {x} {y}')

    def close(self,p):
        os.system(f'adb shell am force-stop {p}')
if __name__ == '__main__':
    # os.system('taskkill /f /im node.exe')
    # os.system('start /b C:/Users/树先生/AppData/Roaming/npm/appium.cmd')
    # time.sleep(5)
    t=Img_mai()
    t.start('com.miui.calculator')
    t.click2('8')
    time.sleep(1)
    t.click3('加')
    time.sleep(1)
    t.click2('3')
    time.sleep(1)
    t.click3('等于')
    time.sleep(1)
    # t.close('com.miui.calculator')



# -*- coding:utf-8 -*-
from selenium import webdriver
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.common.action_chains import ActionChains
import PIL.Image as image
from PIL import Image,ImageEnhance
import time,re, random
import requests
try:
    from StringIO import StringIO
except ImportError:
    from io import StringIO

#爬虫模拟的浏览器头部信息
agent = "Mozilla/5.0 (Windows NT 5.1; rv:33.0) Gecko/20100101 Firefox/33.0"
headers = {
        "User-Agent": agent
        }

# 根据位置对图片进行合并还原
# filename:图片
# location_list:图片位置
#内部两个图片处理函数的介绍
#crop函数带的参数为(起始点的横坐标，起始点的纵坐标，宽度，高度）
#paste函数的参数为(需要修改的图片，粘贴的起始点的横坐标，粘贴的起始点的纵坐标）
def get_merge_image(filename,location_list):
    #打开图片文件
    im = image.open(filename)
    #创建新的图片,大小为260*116
    new_im = image.new("RGB", (278,108))
    im_list_upper=[]
    im_list_down=[]
    # 拷贝图片
    for location in location_list:
        #上面的图片
        if location["y"]==-54:
            im_list_upper.append(im.crop((abs(location["x"]),54,abs(location["x"])+10,166)))
        #下面的图片
        if location["y"]==0:
            im_list_down.append(im.crop((abs(location["x"]),0,abs(location["x"])+10,54)))
    new_im = image.new("RGB", (278,108))
    x_offset = 0
    #黏贴图片
    for im in im_list_upper:
        new_im.paste(im, (x_offset,0))
        x_offset += im.size[0]
    x_offset = 0
    for im in im_list_down:
        new_im.paste(im, (x_offset,54))
        x_offset += im.size[0]
    return new_im

#对比RGB值
def is_similar(image1,image2,x,y):
    pass
    #获取指定位置的RGB值
    pixel1=image1.getpixel((x,y))
    pixel2=image2.getpixel((x,y))
    print(pixel1,pixel2)
    for i in range(0,3):
        # 如果相差超过50则就认为找到了缺口的位置
        if abs(pixel1[i]-pixel2[i])>=80:
            return False
    return True

#计算缺口的位置
def get_diff_location(image1,image2):
    i=0
    # 两张原始图的大小都是相同的260*116
    # 那就通过两个for循环依次对比每个像素点的RGB值
    # 如果相差超过50则就认为找到了缺口的位置
    for i in range(30,278):#有人可能看不懂这个位置为什么要从62开始看最后一张图（图：3）
        for j in range(0,108):
            if is_similar(image1,image2,i,j)==False:
                return  i

#根据缺口的位置模拟x轴移动的轨迹
def get_track(length):
    pass
    list=[]
    #间隔通过随机范围函数来获得,每次移动一步或者两步
    x=random.randint(1,3)
    #生成轨迹并保存到list内
    while length-x>=5:
        list.append(x)
        length=length-x
        x=random.randint(1,3)
    #最后五步都是一步步移动
    for i in range(length):
        list.append(1)
    return list

#滑动验证码破解程序
def main():
    #打开火狐浏览器
    driver = webdriver.Chrome()
    #用火狐浏览器打开网页
    driver.get('https://www.jd.com/')
    driver.maximize_window()
    time.sleep(2)
    driver.find_element_by_xpath('//*[@id="ttbar-login"]/a[1]').click()
    time.sleep(5)
    driver.find_element_by_xpath('/html/body/div[2]/div[2]/div[1]/div/div[3]/a').click()
    time.sleep(1)
    driver.find_element_by_id('loginname').send_keys('najnsjas')
    time.sleep(2)
    driver.find_element_by_id('nloginpwd').send_keys('jhsjasanvs')
    time.sleep(2)
    driver.find_element_by_id('loginsubmit').click()
    time.sleep(2)
    driver.get_screenshot_as_file("D:\python test\\agdad\img.png")#对整个页面截图
    imgelement = driver.find_element_by_xpath('//*[@id="JDJRV-wrap-loginsubmit"]/div/div/div/div[1]/div[2]/div[1]/img')
    p=imgelement.screenshot('img3.png')
    p1=Image.open("D:\python test\\agdad\img3.png").convert('RGB')
    time.sleep(4)
    driver.get_screenshot_as_file("D:\python test\\agdad\img.png")
    imgelement = driver.find_element_by_xpath('/html/body/div[4]/div/div/div/div[1]/div[2]/div[2]/img')  # 定位验证码
    li=imgelement.screenshot('img4.png')
    li1=Image.open("D:\python test\\agdad\img4.png").convert('RGB')
    #计算缺口位置
    loc=get_diff_location(p1, li1)
    print('-------------')
    print(loc)
    #找到滑动的圆球
    element=driver.find_element_by_xpath('//*[@id="JDJRV-wrap-loginsubmit"]/div/div/div/div[2]/div[3]')
    location=element.location
    #获得滑动圆球的高度
    y=location["y"]
    #鼠标点击元素并按住不放
    print ("第一步,点击元素")
    ActionChains(driver).click_and_hold(on_element=element).perform()
    time.sleep(0.15)

    print ("第二步，拖动元素")
    ActionChains(driver).move_to_element_with_offset(to_element=element, xoffset=loc + 30, yoffset=y).perform()
    # ActionChains(driver).drag_and_drop_by_offset(source=element,xoffset=loc+30,yoffset=y).perform()
    #释放鼠标
    ActionChains(driver).release(on_element=element).perform()
    return driver


    #关闭浏览器,为了演示方便,暂时注释掉.
    #driver.quit()

#主函数入口
if __name__ == "__main__":
    main()


import os
import time

class Svn:
    def __init__(self):
        self.svn_server_path='https://LAPTOP-00IBJ9DE:8443/svn/woniu/'
        self.svn_clietn_path='D:\\fghfg'
        self.tomcat_path="D:\\Programs\\apache-tomcat-8.0.42"
        # print(self.tomcat_path)
    def create(self):
        li=os.listdir(self.svn_clietn_path)
        if not li:
            os.system(f'svn  checkout {self.svn_server_path} {self.svn_clietn_path} --username=admin   --password=123456')
        os.system(f'svn  update  {self.svn_clietn_path}')

    def upda(self):
        os.system('taskkill /f /im java.exe')
        x=os.path.exists('{self.svn_clietn_path}\\woniusales.war')
        if x:
            os.system(f'del  /S  /Q {self.svn_clietn_path}\\woniusales.war')
        os.system(f'ant -f {self.svn_clietn_path}\\build.xml')
        li=os.listdir(f'{self.tomcat_path}\\webapps')
        print(li)
        if 'woniusales.war' in li:
            os.system(f'del  /S  /Q {self.tomcat_path}\\webapps\\woniusales.war')
        if 'woniusales' in li:
            os.system(f'rd   /S   /Q  {self.tomcat_path}\\webapps\\woniusales ')
        os.system(f'copy {self.svn_clietn_path}\\woniusales.war {self.tomcat_path}\\webapps\\woniusales.war ')
        time.sleep(2)
        os.system(f'{self.tomcat_path}\\bin\\startup.bat')
        while True:
            x=os.path.exists(f'{self.tomcat_path}\\webapps\\woniusales\\WEB-INF\\classes\\db.properties')
            if x :
                print(x)
                os.system('taskkill /f /im java.exe')
                break
            time.sleep(5)
        with open(f'{self.tomcat_path}\\webapps\\woniusales\\WEB-INF\\classes\\db.properties','w')as f:
            s='''db_url=jdbc:mysql://localhost:3306/woniusales?useUnicode=true&characterEncoding=utf8 
db_username=root
db_password=123456
db_driver=com.mysql.jdbc.Driver'''
            f.write(s)
        os.system(f'{self.tomcat_path}\\bin\\startup.bat ')

if __name__ == '__main__':
    s=Svn()
    s.create()
    s.upda()


import os

import xlrd,requests,csv
base_url='http://192.168.255.180:14200'
rq=requests.session()

def get_data(n):
    li=[]
    li1=[]
    f=xlrd.open_workbook(r"D://qq download//接口测试用例.xls")
    print(f.sheets())
    sheet=f.sheet_by_index(n)
    rows=sheet.nrows
    for i in range(rows):
        x=sheet.row_values(i)
        li.append(x)
    for i in li[7:]:
        li1.append(i)
    t=li[0][1]
    url=base_url+li[1][1]
    method=li[2][1]
    dic={'t':t,'url':url,'method':method,'data':li1}
    return dic

def get_dic(n):
    l=n.split(',')
    dic={}
    for i in l:
        li=i.split('=')
        dic[li[0]]=li[1]
    return dic

def request_t(m,url,data=None):
    if m=='get':
        r=rq.get(url,params=data)
    if m =='post':
        r=rq.post(url=url,data=data)
    if m=='put':
        r=rq.put(url=url,data=data)
    if m=='delete':
        r=rq.request('DELETE',url,params=data)
    return r

def get_csv():
    f = xlrd.open_workbook(r"D://qq download//接口测试用例.xls")
    li=[]
    l=[]
    for i in range(15):
        sheet=f.sheet_by_index(i)
        row=sheet.nrows
        for n in range(row):
            r=sheet.row_values(n)
            li.append(r)
            if n==row-1:
                l.append(li)
                li=[]
    # print(l)
    for i in l:
        name=i[0][1]
        for n in i:
            with open(f'../csv/{name}.csv','a') as f:
                c=csv.writer(f)
                c.writerow(n)
                # print(i)











from selenium import webdriver
from POM12.common.utils import *
import time
class Test_Login:
    def __init__(self,brow):
        self.brow=brow
    def login(self,account,passwd,code):
        self.driver = open_browser(self.brow,base_url)
        self.driver.find_element_by_id('username').send_keys(account)  # 输入账号
        self.driver.find_element_by_id('password').send_keys(passwd)  # 输入密码
        self.driver.find_element_by_id('verifycode').send_keys(code)  # 输入验证码
        login_btn = self.driver.find_element_by_xpath('/html/body/div[4]/div/form/div[6]/button')
        login_btn.click()
        time.sleep(1)
        return self.driver
    def test(self,info):
        """
        测试函数
        :param info: 一条用例（列表）
        :return:
        """
        data = get_data(info[3])   # 处理测试数据，返回一个列表
        self.login(data[0],data[1],data[2])  # 登录操作
        print(f'{self.brow}--{info[1]}--{info[0]}--',end='')
        file = img_path + '/' + get_time() + info[0] + '.png'
        result='success'
        if info[-1] == 'success':
            try:
                assert '首页' not in self.driver.title
                assert '注销' in self.driver.page_source
                if '非管理员' not in info[0]:
                    assert '批次管理' in self.driver.page_source
                print('pass')
            except Exception:
                self.driver.save_screenshot(file)  # 如果用例执行失败，进行截图
                print('fail')
                result='fail'
            finally:
                sql=f'insert into report(`module`,`case`,`data`,`result`,`runtime`,`type`,`version`,`browser`) values("{info[1]}","{info[0]}","{data}","{result}",now(),"ui","v1.0","{self.brow}") '
                cd1.dml(sql)
                self.driver.quit()
        else:
            try:
                assert '首页' in self.driver.title
                print('pass')
            except Exception:
                self.driver.save_screenshot(file)
                print('fail')
                result = 'fail'
            finally:
                sql=f'insert into report(`module`,`case`,`data`,`result`,`runtime`,`type`,`version`,`browser`) values("{info[1]}","{info[0]}","{data}","{result}",now(),"ui","v1.0","{self.brow}") '
                cd1.dml(sql)
                self.driver.quit()
if __name__ == '__main__':
    file = 'D:\python test\\test_woniusales\data\\test_login.csv'
    data = read_csv(file)[1:]
    # print(data)
    tl = Test_Login()
    for i in data:
        tl.test(i)




from POM12.common.utils import *
import time
from POM12.case.test_login import Test_Login
class Test_Add_Customer:
    def __init__(self,brow):
        self.brow=brow
        self.driver = Test_Login(self.brow).login('admin','123456','0000')   # 登录
    def add_customer(self,phone,name,childdate):
        self.driver.find_element_by_link_text('会员管理').click()
        self.driver.find_element_by_id('customerphone').send_keys(phone)
        n = self.driver.find_element_by_id('customername')
        n.clear()
        n.send_keys(name)
        js = f'document.getElementById("childdate").value="{childdate}";'
        self.driver.execute_script(js)  # 执行js，给出生日期输入框设定值
        self.driver.find_element_by_xpath('//button[@onclick="addCustomer()"]').click() # 点击新增
    def test(self,info):
        data = get_data(info[3])   # 处理测试数据，返回一个列表
        result='success'
        self.add_customer(data[0],data[1],data[2])  # 登录操作
        # sql = 'delete from customer where customerid<>101;'
        # cd.dml(sql)  # 执行新增操作前清空会员数据，只保留id为101的一条数据
        self.driver.refresh()  # 刷新页面
        print(f'{self.brow}--{info[1]}--{info[0]}--',end='')
        sql = f'''select * from customer 
                  where customerphone="{data[0]}" and customername="{data[1]}" and childdate="{data[2]}";'''
        r = cd.query_one(sql)
        file = img_path + '/' + get_time() + info[0] + '.png'
        if info[-1] == 'success':
            try:
                assert bool(r) == True
                print('pass')
            except Exception:
                self.driver.save_screenshot(file)  # 如果用例执行失败，进行截图
                print('fail')
                result='fail'
            finally:
                sql=f'insert into report(`module`,`case`,`data`,`result`,`runtime`,`type`,`version`,`browser`) values("{info[1]}","{info[0]}","{data}","{result}",now(),"ui","v1.0","{self.brow}") '
                cd1.dml(sql)
        else:
            try:
                assert bool(r) == False
                print('pass')
            except Exception:
                self.driver.save_screenshot(file)  # 如果用例执行失败，进行截图
                print('fail')
                result='fail'
            finally:
                sql = f'insert into report(`module`,`case`,`data`,`result`,`runtime`,`type`,`version`,`browser`) values("{info[1]}","{info[0]}","{data}","{result}",now(),"ui","v1.0","{self.brow}") '
                cd1.dml(sql)

if __name__ == '__main__':
    file='D:\python test\\test_woniusales\data\\test_add_customer.csv'
    data=read_csv(file)
    t=Test_Add_customer()
    for i in data[1:]:
        t.test(i)



import os,hashlib,re
import csv
import time
from .con_db import Con_DB
from selenium import webdriver

cd = Con_DB('root','123456','woniusales')  # 连接数据库
cd1=Con_DB('root','123456','test_repport')

# base_url = 'http://47.92.203.151:8080/woniusales/'
base_url = 'http://localhost:8080/woniusales/'

base_path = os.path.dirname(os.path.dirname(__file__))   # 获取项目路径
case_path = os.path.join(base_path,'case') # 测试脚本目录
data_path = os.path.join(base_path,'data') # 测试数据目录
report_path = os.path.join(base_path,'report')  # 测试报告目录
driver_path = os.path.join(base_path,'driver')  # 驱动目录
img_path = os.path.join(base_path,'img')  # 失败截图保存目录

def get_time():
    return time.strftime('%Y-%m-%d %H-%M-%S')

def read_csv(file,charset='UTF8'):
    """读取csv文件"""
    with open(file,encoding=charset) as f:
        return list(csv.reader(f))

def get_data(s):
    """处理测试数据，将'account=admin      \npassword=123456'变为列表['admin','123456']"""
    dic = []
    tmp = s.split()

    for i in tmp:  # i = 'password=123456'
        t = i.split('=')
        dic.append(t[1])
    return dic


def open_browser(browser,url):
    """
    根据传入的浏览器名称、url打开对应的浏览器
    :param browser: 浏览器名称
    :param url: 测试地址
    :return:
    """
    driver = None
    if browser.lower() in ('chrome','谷歌'):
        driver = webdriver.Chrome(executable_path='chromedriver')
    elif browser.lower() in ('firefox','火狐'):
        driver = webdriver.Firefox(executable_path='geckodriver')
    elif browser.lower() in ('edge'):
        driver = webdriver.Edge(executable_path='/msedgedriver')
    driver.maximize_window()
    driver.get(url)
    driver.implicitly_wait(30)  # 隐式等待
    return driver

if __name__ == '__main__':
    file = '/Users/my/PycharmProjects/class_78/test_woniusales/data/test_login.csv'
    data = read_csv(file)
    print(data)
    print(get_data(data[1][3]))



import pytest
@pytest.fixture(name='q12',scope='package')
def login(name='admin',passwd='123456'):
    print('hghhvhv')
    if name == 'admin' and passwd == '123456':
        return 'success'
    else:
        return 'account or password error'


import random,time
class Utils:
    def is_continue(self):
        mark = input('继续输入请按1，结束请按任意键：')
        if mark == '1':
            return True
        return False
    def get_time(self):
        return time.strftime('%Y-%m-%d %X')
if __name__ == '__main__':
    str='0123456789'
    print(28%10,str[1:5],str.index('12'),str.split('1'))
    l=[1,2,3,4,1]
    s='0'
    print(s.join('1212'),l[2:5])
    l.sort(reverse=False)
    print(list(str),l)



from selenium import webdriver
class Dr_get:
    dr=None
    @classmethod
    def get_dr(cls):
        if cls.dr==None:
            cls.dr=webdriver.Chrome()
            cls.dr.get('http://localhost:8080/woniusales')
            cls.dr.maximize_window()
        return cls.dr


from selenium import webdriver
from selenium.webdriver.common.by import By
from selenium.webdriver.support.select import Select
from selenium.webdriver.support.ui import WebDriverWait
import time
drive=webdriver.Chrome(executable_path='chromedriver')
drive.maximize_window()
drive.get('http://192.168.11.81:8080/woniusales/')
time.sleep(3)
acc1=drive.find_element_by_id('username')
passwd1=drive.find_element(By.ID,'password')
verifycode1=drive.find_element_by_id("verifycode")
login1=drive.find_elements(By.CLASS_NAME,'btn-primary')
acc1.clear()
acc1.send_keys('admin')
passwd1.send_keys('123456')
verifycode1.send_keys('0000')
drive.find_elements(By.CLASS_NAME,'btn-primary')[1].click()
time.sleep(3)
drive.find_element_by_link_text('批次管理').click()
drive.get_screenshot_as_file('C:\\Users\树先生\Desktop\python\dada.png')
time.sleep(2)
a=drive.find_element_by_id('batchfile')
a.send_keys('D:\python test\\agdad\hjhj.png')
drive.find_element_by_xpath('/html/body/div[4]/div[1]/form[2]/div/input[1]').click()
time.sleep(2)
drive.find_element_by_xpath('/html/body/div[7]/div/div/div[3]/button').click()
drive.quit()








import time

from POM.login_page import Page_login
class Logintest:
    def __init__(self):
        self.dr=Page_login()
    def login(self):
        self.dr.input_user().clear()
        self.dr.input_user().send_keys('admin')
        self.dr.input_pad().clear()
        self.dr.input_pad().send_keys('123456')
        self.dr.input_verfiy().clear()
        self.dr.input_verfiy().send_keys('0000')
        time.sleep(2)
        self.dr.buttun_login().click()

if __name__ == '__main__':
    m=Logintest().login()




# from selenium import webdriver
from appium import webdriver
import time

app={
  "deviceName": "127.0.0.1:62001",
  "platformName": "Android",
  "platformVersion": "7.1.2",
  "appPackage": "com.youdao.calculator",
  "appActivity": "com.youdao.calculator.activities.MainActivity"}
drive=webdriver.Remote('http://127.0.0.1:4723/wd/hub',app)
# w=drive.get_window_size()['width']
# h=drive.get_window_size()['height']
print(drive.get_window_size())
drive.swipe(500,100,100,100,1000)
drive.swipe(500,100,100,100,1000)
drive.swipe(500,100,100,100,1000)
time.sleep(1)
drive.find_element_by_id('com.youdao.calculator:id/guide_button').click()
time.sleep(1)
x=drive.find_element_by_xpath('/hierarchy/android.widget.FrameLayout/android.widget.LinearLayout/android.widget.FrameLayout/android.widget.LinearLayout/android.widget.FrameLayout/android.widget.FrameLayout/android.support.v4.widget.DrawerLayout/android.widget.LinearLayout/android.widget.FrameLayout/android.widget.RelativeLayout/android.widget.LinearLayout[2]/android.widget.LinearLayout/android.widget.LinearLayout[3]/android.view.ViewGroup/android.widget.GridView/android.widget.FrameLayout[3]/android.widget.FrameLayout')
x.click()
x.click()
x.click()
x.click()
x.click()
drive.find_element_by_xpath('/hierarchy/android.widget.FrameLayout/android.widget.LinearLayout/android.widget.FrameLayout/android.widget.LinearLayout/android.widget.FrameLayout/android.widget.FrameLayout/android.support.v4.widget.DrawerLayout/android.widget.LinearLayout/android.widget.FrameLayout/android.widget.RelativeLayout/android.widget.LinearLayout[2]/android.widget.LinearLayout/android.widget.LinearLayout[3]/android.view.ViewGroup/android.widget.GridView/android.widget.FrameLayout[7]/android.widget.FrameLayout').click()
drive.find_element_by_xpath('/hierarchy/android.widget.FrameLayout/android.widget.LinearLayout/android.widget.FrameLayout/android.widget.LinearLayout/android.widget.FrameLayout/android.widget.FrameLayout/android.support.v4.widget.DrawerLayout/android.widget.LinearLayout/android.widget.FrameLayout/android.widget.RelativeLayout/android.widget.LinearLayout[2]/android.widget.LinearLayout/android.widget.LinearLayout[3]/android.view.ViewGroup/android.widget.GridView/android.widget.FrameLayout[20]/android.widget.FrameLayout').click()
drive.find_element_by_xpath('/hierarchy/android.widget.FrameLayout/android.widget.LinearLayout/android.widget.FrameLayout/android.widget.LinearLayout/android.widget.FrameLayout/android.widget.FrameLayout/android.support.v4.widget.DrawerLayout/android.widget.LinearLayout/android.widget.FrameLayout/android.widget.RelativeLayout/android.widget.LinearLayout[2]/android.widget.LinearLayout/android.widget.LinearLayout[3]/android.view.ViewGroup/android.widget.GridView/android.widget.FrameLayout[7]/android.widget.FrameLayout').click()
time.sleep(1)
re=drive.find_element_by_xpath('/hierarchy/android.widget.FrameLayout/android.widget.LinearLayout/android.widget.FrameLayout/android.widget.LinearLayout/android.widget.FrameLayout/android.widget.FrameLayout/android.support.v4.widget.DrawerLayout/android.widget.LinearLayout/android.widget.FrameLayout/android.widget.RelativeLayout/android.widget.FrameLayout/android.webkit.WebView/android.webkit.WebView/android.view.View/android.view.View[1]/android.view.View/android.view.View[2]/android.view.View')
print(re.get_attribute('text'))


import random

from ATM.action.custom_page import Page_customer


class   Customertest:
    def __init__(self):
        self.dr = Page_customer()
    def test_customer_add(self):
        phone=random.randint(111111111,999999999)
        self.dr.do_customer_add(phone)




def sort(list):
    n=len(list)
    for i in range(n-1):
        for j in range(i+1,n):
            if list[i]>list[j]:
                list[i],list[j]=list[j],list[i]
    return list


def sum(n):
    t=0
    l=[]
    for i in range(1,n+1):
        for j in range(1,i+1):
            t=t+j
    return t



if __name__ == '__main__':
    l=[2,3,6,7,10,11,1,1]
    l.reverse()
    print(l)
    reversed(l)
    l.sort(reverse=False)
    print(l)
    l.reverse()
    print(l)
    n=sum(10)
    print(n)
    # l=sort(l)
    # print(l)





import random
class Play:
    def __init__(self,name,turn,time):
        self.name=name
        self.turn=turn
        self.time=time
    # def score(self,out,bout,score):
    #     if out==bout:
    #         score=score
    #     if (out=='石头' and bout=='剪刀') and (out=='剪刀' and bout=='布') and (out=='布' and bout=='石头'):
    #         score+=1
    #     if (out=='石头' and bout=='布') and (out=='剪刀' and bout=='石头') and (out=='布' and bout=='剪刀'):
    #         score-=1
    #     return score
    def scores(self,out,bout):
        # for i in range(turn):
        #     for n in range(time):
        n=0
        if out == bout:
            n=0
            return n
        if (out=='石头' and bout=='剪刀') or (out=='剪刀' and bout=='布') or (out=='布' and bout=='石头'):
            n=1
            return n
        if (out=='石头' and bout=='布') or (out=='剪刀' and bout=='石头') or (out=='布' and bout=='剪刀'):
            n=-1
            return n
class Robet:
    def __init__(self,name):
        self.name=name

    def output(self):
        str=['石头','剪刀','布']
        i=random.choice(str)
        return i


if __name__=='__main__':

    ro1=Robet('ro1')
    zz=Play('zz',3,5)
    score=0
    for i in range(3):
        for n in range(5):
            you=input('请输入')
            ro = ro1.output()
            score=score+zz.scores(you,ro)
            print(score,ro)








# -*- codeing = utf-8 -*- #
from bs4 import BeautifulSoup  # 网页解析，获取数据
import re  # 正则表达式，进行文字匹配`
import urllib.request, urllib.error  # 制定URL，获取网页数据
import xlwt  # 进行excel操作
#import sqlite3  # 进行SQLite数据库操作

findLink = re.compile(r'<a href="(.*?)">')  # 创建正则表达式对象，标售规则   影片详情链接的规则
findImgSrc = re.compile(r'<img.*src="(.*?)"', re.S)
findTitle = re.compile(r'<span class="title">(.*)</span>')
findRating = re.compile(r'<span class="rating_num" property="v:average">(.*)</span>')
findJudge = re.compile(r'<span>(\d*)人评价</span>')
findInq = re.compile(r'<span class="inq">(.*)</span>')
findBd = re.compile(r'<p class="">(.*?)</p>', re.S)

def main():
    baseurl = "https://movie.douban.com/top250?start="  #要爬取的网页链接
    # 1.爬取网页
    datalist = getData(baseurl)
    savepath = "豆瓣电影Top250.xls"    #当前目录新建XLS，存储进去
    # dbpath = "movie.db"              #当前目录新建数据库，存储进去
    # 3.保存数据
    saveData(datalist,savepath)      #2种存储方式可以只选择一种
    # saveData2DB(datalist,dbpath)

# 爬取网页
def getData(baseurl):
    datalist = []  #用来存储爬取的网页信息
    for i in range(0, 10):  # 调用获取页面信息的函数，10次
        url = baseurl + str(i * 25)
        html = askURL(url)  # 保存获取到的网页源码
        # 2.逐一解析数据
        soup = BeautifulSoup(html, "html.parser")
        for item in soup.find_all('div', class_="item"):  # 查找符合要求的字符串
            data = []  # 保存一部电影所有信息
            item = str(item)
            link = re.findall(findLink, item)[0]  # 通过正则表达式查找
            data.append(link)
            imgSrc = re.findall(findImgSrc, item)[0]
            data.append(imgSrc)
            titles = re.findall(findTitle, item)
            if (len(titles) == 2):
                ctitle = titles[0]
                data.append(ctitle)
                otitle = titles[1].replace("/", "")  #消除转义字符
                data.append(otitle)
            else:
                data.append(titles[0])
                data.append(' ')
            rating = re.findall(findRating, item)[0]
            data.append(rating)
            judgeNum = re.findall(findJudge, item)[0]
            data.append(judgeNum)
            inq = re.findall(findInq, item)
            if len(inq) != 0:
                inq = inq[0].replace("。", "")
                data.append(inq)
            else:
                data.append(" ")
            bd = re.findall(findBd, item)[0]
            bd = re.sub('<br(\s+)?/>(\s+)?', "", bd)
            bd = re.sub('/', "", bd)
            data.append(bd.strip())
            datalist.append(data)
    return datalist
# 得到指定一个URL的网页内容
def askURL(url):
    head = {  # 模拟浏览器头部信息，向豆瓣服务器发送消息
        "User-Agent": "Mozilla / 5.0(Windows NT 10.0; Win64; x64) AppleWebKit / 537.36(KHTML, like Gecko) Chrome / 80.0.3987.122  Safari / 537.36"
    }
    # 用户代理，表示告诉豆瓣服务器，我们是什么类型的机器、浏览器（本质上是告诉浏览器，我们可以接收什么水平的文件内容）

    request = urllib.request.Request(url, headers=head)
    html = ""
    try:
        response = urllib.request.urlopen(request)
        html = response.read().decode("utf-8")
    except urllib.error.URLError as e:
        if hasattr(e, "code"):
            print(e.code)
        if hasattr(e, "reason"):
            print(e.reason)
    return html
# 保存数据到表格
def saveData(datalist,savepath):
    print("save.......")
    book = xlwt.Workbook(encoding="utf-8",style_compression=0) #创建workbook对象
    sheet = book.add_sheet('豆瓣电影Top250', cell_overwrite_ok=True) #创建工作表
    col = ("电影详情链接","图片链接","影片中文名","影片外国名","评分","评价数","概况","相关信息")
    for i in range(0,8):
        sheet.write(0,i,col[i])  #列名
    for i in range(0,250):
        # print("第%d条" %(i+1))       #输出语句，用来测试
        data = datalist[i]
        for j in range(0,8):
            sheet.write(i+1,j,data[j])  #数据
    book.save(savepath) #保存


if __name__ == "__main__":  # 当程序执行时
    # 调用函数
     main()
    # init_db("movietest.db")
     print("爬取完毕！")


import time

from ATM.comon.common import Dr_get
from ATM.test.customer_test import Customertest
from ATM.test.login_test import Logintest


class Module:
    def prepare(self):
        n = Customertest()
        self.m = Logintest()
        self.n = n
    def main(self):
        self.m.main_login()
        # self.n.test_customer_add()
    def finish(self):
        self.n.dr.close()


if __name__ == '__main__':
    i=Module()
    i.prepare()
    i.main()
    i.finish()



#coding=utf8
import csv,requests
import random,xlrd

from homework.con_db import Con_DB
cd = Con_DB('root','123456','woniuboss4.0')
def login():
    n=8
    for i in range(450):
        n=n+i
        employee_name0 = '讲师'
        work_id = 'WNCD02' + str(n)
        employee_name=employee_name0+str(n)
        department_id=7
        sex=random.choice(['男','女'])
        sql = f'''insert into employee(`region_id`,`department_id`,`work_id`,`employee_name`,`tel`,`email`,`qq`,`sex`,`position`,`emp_status`,`education`,`university`,`major`,`address`,`source`,`cardnum`,`emergency_contact`,`emergency_tel`,`emegency_relation`,`identity`,`birthday`,`birthday_type`,`entry_time`,`create_time`)
                        values("1","{department_id}","{work_id}","{employee_name}","13138912212","1231@11.com","12121213","{sex}","{employee_name0}","01","01","霍兹莫多","1313","13131恶的手段","达到阿德d","达到阿德d","达到阿德d","达到阿德d","达到阿德d","达到阿德d","1990-06-07","01","2020-07-17","2021-03-02");
                     '''
        cd.dml(sql)
    for i in range(270):
        n=n+i
        employee_name0 = '咨询师'
        work_id = 'WNCD01' + str(n)
        employee_name=employee_name0+str(n)
        department_id=2
        sex=random.choice(['男','女'])
        sql = f'''insert into employee(`region_id`,`department_id`,`work_id`,`employee_name`,`tel`,`email`,`qq`,`sex`,`position`,`emp_status`,`education`,`university`,`major`,`address`,`source`,`cardnum`,`emergency_contact`,`emergency_tel`,`emegency_relation`,`identity`,`birthday`,`birthday_type`,`entry_time`,`create_time`)
                        values("1","{department_id}","{work_id}","{employee_name}","13138912212","1231@11.com","12121213","{sex}","{employee_name0}","01","01","霍兹莫多","1313","13131恶的手段","达到阿德d","达到阿德d","达到阿德d","达到阿德d","达到阿德d","达到阿德d","1990-06-07","01","2020-07-17","2021-03-02");
                     '''
        cd.dml(sql)
    for i in range(180):
        n=n+i
        employee_name0 = '就业老师'
        work_id = 'WNCD00' + str(n)
        employee_name=employee_name0+str(n)
        department_id=3
        sex=random.choice(['男','女'])
        sql = f'''insert into employee(`region_id`,`department_id`,`work_id`,`employee_name`,`tel`,`email`,`qq`,`sex`,`position`,`emp_status`,`education`,`university`,`major`,`address`,`source`,`cardnum`,`emergency_contact`,`emergency_tel`,`emegency_relation`,`identity`,`birthday`,`birthday_type`,`entry_time`,`create_time`)
                        values("1","{department_id}","{work_id}","{employee_name}","13138912212","1231@11.com","12121213","{sex}","{employee_name0}","01","01","霍兹莫多","1313","13131恶的手段","达到阿德d","达到阿德d","达到阿德d","达到阿德d","达到阿德d","达到阿德d","1990-06-07","01","2020-07-17","2021-03-02");
                     '''
        cd.dml(sql)
def quan():
    sql=f'''select * from employee where employee_id>8'''
    l=cd.query_all(sql)
    for i in l:
        name=i[3]
        pwd='DAF2ABB2A61A210C82E374AC2A5BFFD6'
        pwd2='DAF2ABB2A61A210C82E374AC2A5BFFD6'
        emil=i[6]
        phone=i[5]
        emp_id=i[0]
        sql=f'''insert into system_user(`name`,`pwd`,`pwd2`,`status`,`passwd_status`,`passwd2_status`,`icon`,`email`,`phone`,`employee_id`,`createdate`)
                values("{name}","{pwd}","{pwd2}","01","1","1","images/guest.jpg","{emil}","{phone}","{emp_id}","2021-03-03")
        '''
        cd.dml(sql)
def shouqun():
    sql = f'''select system_user.id,employee.position from system_user,employee where system_user.id=employee.employee_id and system_user.id>197'''
    l = cd.query_all(sql)
    print(l[0:3])
    role_ids = 0
    for i in l:
        user_id1=i[0]
        user_id=i[1]
        if user_id=='讲师':
            role_id=14
        elif user_id=='咨询师':
            role_id=13
            role_ids = 24
        elif user_id=='就业老师':
            role_id=15
        sql=f'''insert into system_user_role(`user_id`,`role_id`) values("{user_id1}","{role_id}");'''
        cd.dml(sql)
        if role_ids==24 and user_id=='咨询师':
            sql = f'''insert into system_user_role(`user_id`,`role_id`) values("{user_id1}","{role_ids}");'''
            cd.dml(sql)

def student():
    li=[]
    for i in range(10000):
        name='张三'+str(i)
        sex=random.choice(['男','女'])
        age=random.choice(['21','22','23','24','25','26'])
        zhuan='本科'
        xueyuan='霍格沃兹'
        zhuanye='计算机'
        jinyan=random.choice([1,2,3])
        phone='136'+str(random.randint(11111111,99999999))
        emal=str(i)+'@123.com'
        l=[name,sex,age,zhuan,xueyuan,zhuanye,jinyan,phone,emal,'8000','测试','自然流量']
        # l=f'[{name},{sex},{age},{zhuan},{xueyuan}，{zhuanye},{jinyan},{phone},{emal},8000,测试,自然流量]'
        li.append(l)
    with open('D:\qq download\woniuboss测试版4.0\测试版4.0\专属简历模板.csv','a+',encoding='utf-8',newline="\n") as f:
        w=csv.writer(f)

        w.writerows(li)

def fuquan(na):
    rq = requests.session()
    url = 'http://192.168.11.7:8080/woniuboss/login/userLogin'
    data = {'userName': 'WNCD000',
            'userPass': 'woniu123',
            'checkCode': '0000',
            'remember': 'Y'}
    res = rq.post(url=url, data=data)

    url1='http://192.168.11.7:8080/woniuboss/user/saveSetRole'
    data1 = {'userId': na,
             'roleId[]': '14'}
    res1 = rq.post(url=url1, data=data1)

def li():
    sql = '''select work_id from employee where position = '咨询师';'''
    l = cd.query_all(sql)
    li=[]
    lis=[]
    i=1
    for n in range(731587, 732572):
        i+=1
        li.append(n)
        if i%3==0:
            lis.append(li)
            li=[]
    return l,lis


def fen(n,j):
    rq = requests.session()
    url = 'http://192.168.11.7:8080/woniuboss/login/userLogin'
    data = {'userName': 'WNCD002',
            'userPass': 'Woniu1234',
            'checkCode': '0000',
            'remember': 'Y'}
    res = rq.post(url=url, data=data)
    url1='http://192.168.11.7:8080/woniuboss/allot/saveResourceToPool'
    data={'arr[]':n,'work_id':j}
    r=rq.post(url=url1, data=data)


def fem(i,j):
    sql=f'''update customer set work_id="{i}" where customer_id="{j}";'''
    cd.dml(sql)

if __name__ == '__main__':
    l,li=li()
    # print(l)
    x=732396
    for i in l[1:]:
        x+=1
        fem(i[0],x)










import pytest,os
from test_book.common.utils import read_csv,data_bath,get_data,base_url,request,get_time,report_bath,case_bath
t=get_time()
pytest.main(['-v',f'--html={report_bath}/{t}.html',case_bath])





import socket,re
# soc=socket.socket(socket.AF_INET,socket.SOCK_STREAM)
# ip='192.168.11.222'
# port=5321
# soc.bind((ip,port))
# soc.listen(5)
# a,adress=soc.accept()
# a1,adress1=soc.accept()
# msg=a.recv(1024)
# msg=msg.decode('utf8')
# a1.send(msg.encode('utf8'))
s = '123!##a1sd12_as^&12789_asd9%&*'
r=re.findall('\d{2,}',s)
print(r)
r.sort(reverse=True)
print(r)
a=str.join(',',r)
a=re.sub(',','',a)
print(a)


from woniuticket.coomon.common import get_data, get_dic, request_t
import pytest
case=get_data(14)
@pytest.mark.parametrize('info',case['data'])
def test_main1(info):
    if info[2]!='success':
        pytest.skip()
    else:
        data=get_dic(info[1])
        url='http://127.0.0.1:8080/woniusales/user/login'
        code=info[2]
        message=info[3]
        method=case['method']
        r=request_t(m=method,url=url,data=data)
        print(r.json())
        assert code in r.json()['code']
        assert message in r.json()['message']

# def teardown_function():
#     r=request_t('delete','http://192.168.255.180:14200/api-user/user/userlogout')
#     print(r.json())
#     return r

if __name__ == '__main__':
    pytest.main(['-v',__file__])
    # print(case)


import pytest
import requests
from woniuticket.coomon.common import get_data, get_dic, request_t
def setup_function():
    r1=request_t('get','http://192.168.255.180:14200/cinema-stage/admin/login',{'username':'小刘','password':'123456'})
    return r1
case=get_data(15)
@pytest.mark.parametrize('info',case['data'])
def test_main(info):
    data=get_dic(info[1])
    url=case['url']
    code=info[2]
    message=info[3]
    method=case['method']
    r=request_t(m=method,url=url,data=data)
    if code=='null':
        code=None
    if message=='null':
        message=None
    print(r.json())
    if code=='N/A':
        assert message in r.json()['message']
    elif message==None:
        assert code==r.json()['code']
    else:
        assert code == r.json()['code']
        assert message in r.json()['message']

def teardown_function():
    r1=request_t('delete','http://192.168.255.180:14200/api-user/user/userlogout')
if __name__ == '__main__':
    pytest.main(['-v',__file__])




import redis
con=redis.ConnectionPool(host='192.168.153.128',port=6379,db=0,decode_responses=True)
red=redis.Redis(connection_pool=con)
red.set('name','addmin')
red.hset('dic',key='adc',value='bc')
red.hmset('dic',mapping={'dad':'adad','adadad':'1231'})
print(red.get('name'))
print(red.hgetall('dic'))


# coding=utf-8
'''
服务层
'''
import copy
import itertools
import random
import sys

from mud.data import m1, m2, m3, items1, items2, items3, items4, items5, items6, player, skills1, skills2, skills3, user

postion = random.sample(list(itertools.product(range(10), range(10))), 50)
page='main'

#注册
def regist(nickname,passwd,checkpass):
    if 8<=len(nickname)<=20  and nickname.isalnum()==True and 6<=len(passwd)<=12 and checkpass==passwd:
        print('注册成功')
        user[nickname]=passwd
        with open('user.txt','a',encoding='utf-8') as f:
            f.write(str(user)+'\n')
        flag=True
        return flag
    else:
        print('注册失败')
        flag=False
        return flag
#登录
def login(nickname,passwd):
    n = 1
    for i in range(5):
        with open('user.txt','r',encoding='utf-8') as f:
            users=f.readlines()
            for user in users:
                user.replace('\n','')
                user=eval(user)
                if user[nickname]==passwd:
                    print('登录成功')
                    page='game'
                    return page
                    break
                else:
                    print('登录失败')
                    n= n+1
                    nickname = input('输入用户名')
                    passwd = input('密码')
                    if n==5:
                        print('1.账户已锁,请联系管理员','2.退出')
                        x=input('输入指令')
                        if x=='1':
                            page='adminlogin'
                            return page
                            break
                        elif x=='2':
                            sys.exit(0)
            return False
#初始化地图
def initmap():
    width=10
    height=10
    return width,height
#初始化怪物
def init_monster():
    # ms = []
    m=[m1,m2,m3]
    item = [items1, items2, items3, items4, items5, items6]
    # postion = random.sample(list(itertools.product(range(10), range(10))),50)
    # print(postion)
    # for i in range(50):
    #     mx = random.choice(m)
    #     mx['x,y']=(0,0)
    #     mx['x,y']= postion[i]
    #     mx['item'] = random.choice(item)
    #     mx=mx
    #     ms.append(mx)
    mx = random.choice(m)
    mx['item'] = random.choice(item)
    return mx
#初始化角色
def init_player(nickname):
    player['name']=nickname
    skills=[skills1,skills2,skills3]
    player['skills']=skills
    return player
#角色移动
def move(player,direct=''):
    x=int(player['x,y'][0])
    y=int(player['x,y'][1])
    if direct=='w':
        player['x,y'] = (x, y + 1)
        if y>9:
            player['x,y'] = (x, 9)
            print('/t已经到达边界')
    elif direct=='s':
        player['x,y']= (x,y-1)
        if y<0:
            player['x,y'] = (x, 0)
            print('/t已经到达边界')
    elif direct=='a':
        player['x,y'] =(x-1,y)
        if x<0:
            player['x,y'] = (0, y)
            print('/t已经到达边界')
    elif direct=='d':
        player['x,y'] = (x+1,y)
        if x>9:
            player['x,y'] = (9, y)
            print('/t已经到达边界')
    return player
#检测碰撞
def checkhit(player,postion):
    if player['x,y'] in postion:
        return True
#发生战斗
def battle(player,master):
    for i in range(1):
        hp_man = player['hp'] + player['defence']
        hp_master = master['hp'] + master['defence']
        mp_man=player['mp']
        damage_man=player['damage']
        damage_master=master['damage']
        while hp_man > 0 :
            skill = input('输入攻击方式')
            if mp_man>=0:
                if skill == '1':
                    hp_master = hp_master - damage_man
                    hp_man = hp_man - damage_master
                    print(hp_man,hp_master,mp_man)
                elif skill == '2':
                    hp_master = hp_master - 30
                    hp_man = hp_man - damage_master
                    mp_man=mp_man-10
                    print(hp_man, hp_master,mp_man)
                elif skill == '3':
                    hp_master = hp_master - 50
                    hp_man = hp_man - damage_master
                    mp_man = mp_man - 20
                    print(hp_man, hp_master,mp_man)
                elif skill == '4':
                    hp_man = hp_man - damage_master+30
                    mp_man = mp_man - 30
                    print(hp_man, hp_master,mp_man)
            if hp_master <= 0:
                print('针不戳')
                player['hp']=hp_man
                player['mp']=mp_man
                page='get_item'
                return page
            if player['mp']<0:
                print('蓝量不足，不能使用技能')
                if skill == '1':
                    hp_master = hp_master - damage_man
                    hp_man = hp_man - damage_master
                    print(hp_man,hp_master,mp_man)
            if hp_man <= 0:
                print('游戏结束')
                sys.exit(0)
#装备拾取
def get_item(player,master):
    item=master['item']
    y=input(f'是否拾取装备{item} y/n')
    if y=='y':
        player['item']=item
        if item['type']==1:
            player['damage']=player['damage']+item['value']
        elif item['type']==2:
            player['defence'] = player['defence'] + item['value']
        elif item['type']==3:
            player['hp'] = player['hp'] + item['value']
    return player
#存盘
def save(filename,player):
    with open(filename,'a',encoding='utf-8') as f:
        f.write(str(player))
#读盘
def load(filename):
    with open(filename,'r',encoding='utf-8')as f:
        player=eval(f.read())
    return player





#coding=utf8
import requests,time,threading
import psutil
from xingneng.common import get_data, get_res

res_time=[]
res_get=[]

def get_run_time(func):
    def inner(self, *args, **kwargs):
        t1 = time.time()
        res = func(self, *args, **kwargs)
        t2 = time.time()
        print(f'响应时间：{int((t2 - t1) * 1000)}ms')
        res_time.append(int((t2 - t1) * 1000))
        return res
    return inner


class Search():
    def __init__(self):
        self.r=requests.session()
    @get_run_time
    def login(self):
        url='http://127.0.0.1:8080/woniusales/user/login'
        data={'username':'admin','password':'123456','verifycode':'0000'}
        res=self.r.post(url,data=data)
        print(f'发送登录请求,登录结果为{res.text}')
        x=get_res(res)
        print(f'获取登录请求大小为{x}Bety')
        res_get.append(x)

    @get_run_time
    def login_1(self):
        url = 'http://127.0.0.1:8080/woniusales/'
        res=self.r.get(url)
        x = get_res(res)
        print(f'获取登录请求大小为{x}Bety')
        res_get.append(x)
    @get_run_time
    def login_source(self):
        url1='http://127.0.0.1:8080/woniusales/library/css/bootstrap.css'
        url2='http://127.0.0.1:8080/woniusales/library/css/sitemain.css'
        url3='http://127.0.0.1:8080/woniusales/library/js/jquery-1.11.0.min.js'
        zurl=[url1,url2,url3]
        for i in zurl:
            res=self.r.get(url=i)
        print('获取登录资源')
    @get_run_time
    def hit_customer(self):
        url='http://127.0.0.1:8080/woniusales/customer'
        res=self.r.get(url)
        print('发送点击会员管理请求')
        x = get_res(res)
        print(f'获取登录请求大小为{x}Bety')
        res_get.append(x)
    @get_run_time
    def seacher(self):
        url='http://127.0.0.1:8080/woniusales/customer/search'
        data={'customerphone':'5454654654','page':'1'}
        res=self.r.post(url=url,data=data)
        print(f'发送查询会员请求,请求结果为{res.text}')
        x = get_res(res)
        print(f'获取登录请求大小为{x}Bety')
        res_get.append(x)

    def run_main(self):
        for i in range(1):
            self.login_1()
            time.sleep(1)
            self.login_source()
            time.sleep(1)
            self.login()
            time.sleep(2)
            self.hit_customer()
            time.sleep(1)
            self.seacher()

if __name__ == '__main__':
    a=Search()
    for i in range(1):
        th=threading.Thread(target=a.run_main)
        th.setDaemon(True)
        th.start()
    th.join()
    avg_t,max_t,min_t=get_data(res_time)
    avg_r,max_r,min_r=get_data(res_get)
    print(avg_t,max_t,min_t)
    print(avg_r,max_r,min_r)


import time

import pymysql
from selenium import webdriver
class Dr_get:
    dr=None
    @classmethod
    def get_dr(cls):
        if cls.dr==None:
            cls.dr=webdriver.Chrome()
            cls.dr.get('http://localhost:8080/woniusales')
            cls.dr.maximize_window()
        return cls.dr
    @classmethod
    def data_get(cls,file):
        with open(file,encoding='utf8') as f:
            data=f.readlines()
        return data

    @classmethod
    def imagne(cls):
        phonename='..\imagne'+time.strftime('-%H%M%S.png')
        cls.dr.save_screenshot(phonename)
        return phonename

    @classmethod
    def con_db_dql(cls,version,module,types,title,result,error,image):
        con=pymysql.connect(user='root',password='123456',host='localhost',port='8080',db='cbtreport',charset='utf8')
        cur=con.cursor()
        sql=f'insert into cbtreport(testversion,testmodule,testtype,casetitle,testresult,testerror,testimage,testtime) values("{version}","{module}","{types}","{title}","{result}","{error}","{image}",now())'
        cur.execute(sql)
        cur.fetchall()
        cur.close()
        con.close()

    @classmethod
    def con_db_dml(cls,sql):
        con = pymysql.connect(user='root', password='123456', host='localhost', port='8080', db='cbtreport',
                              charset='utf8')
        cur = con.cursor()
        cur.execute(sql)
        con.commit()
        cur.close()
        con.close()


    @classmethod
    def report_get(cls,old,new):
        file='..\\report'+'report_woniu'+time.strftime('-%H%M%S.html')
        with open('D:\python test\ATM\\report\\report_sample.html',encoding='utf8',mode='a+') as f:
            m=f.read()
            m.replace(old,new)
        with open(file,encoding='utf8',mode='a+') as f:
            f.write(m)





import copy
import re

import requests
import time
def get_bage():
    a=requests.get('https://app.mi.com/topList')
    b=a.text
    li=re.findall("href=\"/details\?id=(.*?)\"",b)
    li_1=list(set(li))
    # print(li_1)
    for i in li_1:
        c=requests.get(f'https://app.mi.com/details?id={i}')
        li1=re.findall("href=\"/download/(.*?)\"",c.text,re.S)
        # print(li1)
        if li1:
            d=requests.get(f'https://app.mi.com/download/{li1[0]}').content
            print(f'{i}正在下载')
            with open(f'D:\\测试\\app\\{i}.apk','ab') as f:
                f.write(d)
                print(f'{i}下载完成')

if __name__ == '__main__':
    z=1
    a=2
    c=z
    z=a
    a=c
    print(a,z)


import random
import sys

from dteacher.con_db import Con_DB
from dteacher.utils import Utils
from flask import Flask,jsonify,request,render_template,make_response

app=Flask(__name__)
cd=Con_DB('root','123456','test')
utils=Utils()
import time
# class App:
#     def __init__(self,con_db,utils):
#         self.con_db = con_db      # 数据库操作类的对象
#         self.utils = utils
#         self.welcome()
@app.route('/login',methods=['GET','POST'])
def login():
    if request.method=='GET':
        return jsonify({'code':'1004','message':'method erro'})
    else:
        account=request.form.get('account')
        passwd=request.form.get('passwd')
        sql = f'select * from userinfo where account="{account}";'
        userinfo = cd.query_one(sql)   # 查询指定用户的信息
        if userinfo:  # 判断账号是否存在
                if passwd == userinfo[2]:  # 判断密码是否正确
                    res=make_response(jsonify({'code':'10001','message':'登录成功'}))
                    res.set_cookie('account',account,max_age=60)
                    return res
                else:
                    return jsonify({'code':'1002','message':'密码错误'})
        else:
            return jsonify({'code':'1003','message':'用户不存在'})
@app.route('/index',methods=['GET'])
def index():
    return render_template('login.html')
@app.route('/reg',methods=['GET','POST'])
def reg():
    if request.method=='GET':
        return jsonify({'code':'1004','message':'method erro'})
    else:
        account=request.form.get('account')
        passwd=request.form.get('passwd')
        realname=request.form.get('realname')
        phone=request.form.get('phone')
        sql = f'select * from userinfo where account="{account}";'
        userinfo = cd.query_one(sql)   # 查询指定用户的信息
        if not userinfo:
            sql = f'''insert into userinfo(`account`,`passwd`,`realname`,`phone`,`role`)
                     values("{account}","{passwd}","{realname}","{phone}","0");
                  '''
            cd.dml(sql)
            return jsonify({'code':'1001','message':'注册成功'})
        else:
            return jsonify({'code':'1002','message':'用户名已存在'})
# @app.route('/welcome',methods=['GET'])
# def welcome():
#     print('------ 欢迎使用蜗牛图书管理系统 -------')
#     print('------ 1 登录  2 注册  3 退出 -------')
#     s = input('请选择服务：')
#     if s == '1':
#         return
#     elif s == '2':
#         pass
#     else:
#         pass
# class Ordinary:
#     """非管理员"""
#     def __init__(self,userinfo,con_db,utils):
#         self.userinfo = userinfo      # 当前登录用户信息
#         self.con_db = con_db     # 数据库连接对象
#         self.utils=utils
#         # self.main()
#     def main(self):
#         while True:
#             print('------------ 请选择服务 ------------')
#             print('             1 借阅信息             ')
#             print('             2 图书查询             ')
#             print('             3 借阅图书             ')
#             print('             4 归还图书             ')
#             print('             5 退   出             ')
#             s = input('服务：')
#             if s == '1':
#                 self.query_borrow_info()
#             elif s == '2':
#                 self.query_book_info()
#             elif s == '3':
#                 self.borrow_book()
#             elif s == '4':
#                 self.return_book()
#             else:
#                 exit()
@app.route('/query_borrow_info',methods=['GET'])
def query_borrow_info():
    """查询借阅信息"""
    get_cookie=request.cookies.get('account')
    if get_cookie:
        account=get_cookie
        sql = f'select * from bookborinfo where account="{account}";'
        r = cd.query_all(sql)
        if bool(r):
            return jsonify({'code':'1001','message':'查询成功'})
        else:
            return jsonify({'code':'1002','message':'暂无借阅信息'})
    else:
        return jsonify({'code':'1003','message':'请登录系统'})
        # (f'{"序号":4}\t{"编号":4}\t{"书名":12}\t{"借阅日期":8}\t状态')
        # (f'{i+1:^4}\t{j[1]:4}\t{j[2]:12}\t{str(j[3]).split()[0]}\t{"已归还" if j[-1] else "未归还"}')
@app.route('/query_book_info/<string:a>',methods=['GET'])
def query_book_info(a):
    '''图书查询（支持编号、书名的模糊查询）'''
    get_cookie = request.cookies.get('account')
    if get_cookie:
        # a = request.args.get('bookid')
        sql = f'''select * from book where bookid="{a}" or name like "%{a}%";'''
        r = cd.query_all(sql)
        print(r)
        return jsonify({'code':'1001','message':'查询成功'})
    else:
        return jsonify({'code':'1002','message':'请登录系统'})
@app.route('/borrow_book',methods=['GET','POST'])
def borrow_book():
    '''借阅'''
    if request.method=='GET':
        return jsonify({'code':'1004','message':'method erro'})
    else:
        get_cookie = request.cookies.get('account')
        if get_cookie:
            account=get_cookie
            a=request.form.get('id')
            c=request.form.get('count')
            sql=f'select * from book where bookid ="{a}";'
            r=cd.query_one(sql)
            print(r)
            c=int(c)
            b=int(r[-1])
            if b>=c:
                m=b-c
                sql1=f'''update book set count= "{m}" where bookid="{a}";'''
                sql2=f'''insert into bookborinfo (`account`,`bookid`,`bro_date`)values("{account}","{a}","{utils.get_time()}");'''
                cd.dml(sql1,sql2)
                return jsonify({'code':'1001','message':'借阅成功'})
            else:
                return jsonify({'code':'1002','message':'图书数量不够'})
        else:
            return jsonify({'code':'1003','message':'请登录系统'})
@app.route('/return_book',methods=['GET','POST'])
def return_book():
    if request.method=='GET':
        return jsonify({'code':'1003','message':'method erro'})
    else:
        get_cookie = request.cookies.get('account')
        if get_cookie:
            account=get_cookie
            a=request.form.get('id')
            b=request.form.get('count')
            sql1 = f'''update book set count=(count+"{b}") where bookid="{a}";'''
            sql2 = f'''update bookborinfo set return_date="{utils.get_time()}" where bookid="{a}" and account="{account}";'''
            cd.dml(sql1,sql2)
            return jsonify({'code': '1001', 'message': '归还成功'})
        else:
            return jsonify({'code':'1002','message':'请登录系统'})
    #
    #
    # class Administrator(Ordinary):
    #     """管理员类，继承非管理员类"""
    #     def main(self):
    #         """重写父类方法"""
    #         while True:
    #             print('------ 请 选 择 服 务 ------')
    #             print('       1 借阅信息       ')
    #             print('       2 图书查询       ')
    #             print('       3 借阅图书       ')
    #             print('       4 归还图书       ')
    #             print('       5 添加图书       ')
    #             print('       6 删除图书       ')
    #             print('       7 退   出       ')
    #             s = input('服务：')
    #             if s == '1':
    #                 self.query_borrow_info()
    #             elif s == '2':
    #                 self.query_book_info()
    #             elif s == '3':
    #                 self.borrow_book()
    #             elif s == '4':
    #                 self.return_book()
    #             elif s == '5':
    #                 self.add_book()
    #             elif s == '6':
    #                 self.delete_book()
    #             else:
    #                 exit()
    #
@app.route('/add_book',methods=['GET','POST'])
def add_book():
    if request.method=='GET':
        return jsonify({'code':'1007','message':'method erro'})
    else:
        get_cookie = request.cookies.get('account')
        if get_cookie:
            account=get_cookie
            sql=f'select role from userinfo where account="{account}";'
            r=cd.query_one(sql)
            if r[0]=='1':
                a = request.form.get('id')
                b = request.form.get('name')
                c = request.form.get('author')
                d = request.form.get('count')
                sql=f'select * from book where bookid="{a}" and name="{b}" and author="{c}";'
                r=cd.query_one(sql)
                if bool(r):
                    sql=f'update book set count=(count+"{d}") where bookid ="{a}";'
                    cd.dml(sql)
                    return jsonify({'code':'1001','message':'添加成功'})
                else:
                    sql = f'select * from book where bookid="{a}";'
                    r = cd.query_one(sql)
                    if bool(r):
                        return jsonify({'code':'1003','message':'图书编号已存在'})
                    else:
                        sql = f'select * from book where name="{b}" and author="{c}";'
                        r = cd.query_one(sql)
                        if bool(r):
                            return jsonify({'code':'1004','message':'图书已存在'})
                        else:
                            sql = f'insert into book (`bookid`,`name`,`author`,`count`)values ("{a}","{b}","{c}","{d}");'
                            cd.dml(sql)
                            return jsonify({'code':'1002','message':'新增成功'})
            else:
                return jsonify({'code':'1005','message':'请登录管理员账号'})
        else:
            return jsonify({'code':'1006','message':'请登录系统'})
@app.route('/delete_book',methods=['GET','POST'])
def delete_book():
    if request.method=='GET':
        return jsonify({'code':'1005','message':'method erro'})
    else:
        get_cookie = request.cookies.get('account')
        if get_cookie:
            account = get_cookie
            sql = f'select role from userinfo where account="{account}";'
            r = cd.query_one(sql)
            if r[0] == '1':
                a=request.form.get('name')
                sql=f'select * from book where name="{a}";'
                r=cd.query_one(sql)
                if bool(r):
                    sql=f'''delete from book where name="{a}";'''
                    r=cd.dml(sql)
                    return jsonify({'code': '1001', 'message': '删除成功'})
                else:
                    return jsonify({'code': '1002', 'message': '图书不存在'})
            else:
                return jsonify({'code': '1003', 'message': '请登录管理员账号'})
        else:
            return jsonify({'code': '1004', 'message': '请登录系统'})
if __name__ == '__main__':
    app.run(host='0.0.0.0',port=4321,debug=True)





#cording=utf-8

'''例2：
    声明一个资金类，保存3个类属性，分别保存销售总额、食品类销售额、服饰类销售额；声明类方法用于更新销售额，根据销售的商品类别进行更新
声明一个销售类，包含实例属性（商品名称、类别、单价、销售数量），销售完成后需要更新销售总额、不同品类销售额
'''
import random
import time,threading


class Money:
    toal=0
    foodmoney=0
    clothmoney=0
    @classmethod
    def update(cls,type,price,number):
        cls.toal+=price*number
        if type=='衣服':
            cls.clothmoney+=price*number
        if type=='食品':
            cls.foodmoney+=price*number

class Sale:
    def __init__(self,name,type,price,number):
        self.name=name
        self.type=type
        self.price=price
        self.number=number
        Money.update(self.type,self.price,self.number)

'''
例2：球员投篮训练，统计在2分钟内的训练成绩
    球员类：包含属性姓名、历史投篮命中率，投篮次数，命中数；以及投篮方法
每次投篮后随机调整1-3秒
命中率模拟： 比如命中率为90%，可以声明一个列表，列表中包含10个元素，9个为'命中'，1个为'未命中'，每次投篮随机从列表中选择一个元素即可
'''
#hgj
class Player:
    def __init__(self,name,hisrate,frequece,rate,meth):
        self.name=name
        self.hisrate=hisrate
        self.frequece=frequece
        self.rate=rate
        self.meth=meth
    def rate(self):
        a=self.rate*100
        b=100-a
        ratelist=[]
        for i in range(int(a)):
            ratelist.append('命中')
        for i in range(int(b)):
            ratelist.append('未命中')
        return  ratelist
    def scores(self, score):
        time1=time.time()
        c = Player.rate(self)
        while True:
            time2=time.time()
            s = random.randint(1,3)
            time.sleep(s)
            i=random.choice(c)
            if i=='命中':
                score+=1
            elif i=='未命中':
                score=score
            print(f'{self.name}的分数是{score:4}')
            if time2-time1>120:
                return score
                break
# def func(play,playerinfo):
#     play






if __name__=='__main__':
    s1=Sale('大大','食品',12,12)
    print(Money.foodmoney,Money.clothmoney,Money.toal)
    # p1=Player('哈登',0.99,20,0.91,123)
    # print(p1.scores(0))



import os,time,csv,requests,hashlib,re
base_bath=os.path.dirname(os.path.dirname(__file__))
case_bath=os.path.join(base_bath,'case')
data_bath=os.path.join(base_bath,'data')
report_bath=os.path.join(base_bath,'report')
base_url='http://192.168.11.108:5000'
rq=requests.session()

def request(url,method,data,hearder=None):
    if method.lower()=='get':
        r=rq.get(url=url,params=data,headers=hearder)
    elif method.lower()=='post':
        r=rq.post(url=url,data=data,headers=hearder)
    return r

def get_time():
    return time.strftime('%Y-%m-%d %H-%M-%S')

def read_csv(file,charset='utf8'):
    with open(file,encoding=charset) as f:
        return list(csv.reader(f))

def get_data(s):
    dic={}
    tmp=s.split()
    for i in tmp:
        t=i.split('=')
        dic[t[0]]=t[1]
    return dic

def loginadmin():
    url='http://192.168.11.108:5000/login'
    data={'account':'admin','passwd':'admin123'}
    r=request(url,method='post',data=data)
    return r

def get_md5(s):
    return hashlib.md5(s.encode('utf8')).hexdigest()
def add_bug(module,title,steps):
    """
    在禅道中提交bug
    :param module:模块（序号）
    :param title:缺陷名称
    :param assignedTo:缺陷分配给谁
    :param steps:缺陷详细描述
    :param uid:禅道用户id
    :return:
    """
    url_login='http://47.92.203.151:8000/zentaopms/www/user-login.html'
    url_bug='http://47.92.203.151:8000/zentaopms/www/bug-create-2-0-moduleID=2.html'
    rq=requests.session()
    #对登录页面发起get请求，获取verifyRand
    r=rq.get(url=url_login)
    rand=re.findall("'verifyRand' value='(\d+)'  />",r.text)
    print(rand)
    data={'account':'admin','verifyRand':rand,
          'referer':'http://47.92.203.151:8000/zentaopms/www/my',
          'password':get_md5(get_md5('123456')+str(rand))}

    r=rq.post(url=url_login,data=data)
    print(r.text)
    r1 = rq.get(url=url_bug)
    print(r1.text)
    uid = re.findall("var kuid = '(\w+)';", r.text)
    print(uid)
    data={'product':(None,'2'),'module':(None,f'{module}'),'project':(None,'1'),
          'openedBuild[]':(None,'trunk'),'assignedTo':(None,'hanzhitai'),'type':(None,'codeerror'),
          'title': (None, f'{title}'), 'severity': (None, '3'), 'pri': (None, '2'),'steps': (None, f'{steps}'),
          'oldTaskID': (None, '0'),'uid': (None, '600bd980e6121')}
    r=rq.post(url=url_bug,files=data)
if __name__ == '__main__':
    r=add_bug('1','aas','asas')








import pymysql
def con_db():
    # 连接数据库
    con, cur=None,None
    try:
        con = pymysql.connect(user='root',
                          password='123456',
                          host='localhost',
                          port=3306,
                          db='test',
                          charset='utf8')
    except Exception as e:
        print(e)
    else:
        cur = con.cursor()  # 创建游标
    return con,cur
def is_continue():
    mark = input('继续输入请按1，结束请按任意键：')
    if mark == '1':
        return True
    return False
def login(cur):
    """
    登录
    :param cur: 游标
    :return:
    """
    # 接收外部输入的账号和密码
    print('----------- 登录 -----------')
    flag_1, flag_2 = True, True  # 控制内层和外层循环
    error = 0  # 计数器，保存密码连续错误次数
    while flag_1:
        account = input('账 号：')
        sql = f'select * from userinfo where account="{account}";'
        if cur.execute(sql) == 1:  # 判断账号是否存在
            info = cur.fetchone()  # 获取用户信息
            while flag_2:
                passwd = input('密 码：')
                if passwd == info[2]:  # 判断密码是否正确
                    print('登录成功')
                    flag_1, flag_2 = False, False
                else:
                    error += 1
                    if error == 3:
                        print('密码已连续错误3次，程序结束')
                        flag_1, flag_2 = False, False
                    else:
                        print('密码错误，请重新输入')
                        flag_2 = is_continue()
                        flag_1 = flag_2

        else:
            print('账号不存在')
            flag_1 = is_continue()


def regist(username,passwd,realname,phone):
    print('----------- 注册 -----------')
    flag_1, flag_2 = True, True  # 控制内层和外层循环
    error = 0  # 计数器，保存密码连续错误次数
    while True:
        con,cur=con_db()
        sql = f'select * from userinfo where account="{username}";'
        if cur.execute(sql) == 1:  # 判断账号是否存在
            print('账户名已存在')
        else:
            sql2=f'INSERT INTO `userinfo`(`account`, `passwd`, `realname`, `phone`, `role`) VALUES ("{username}","{passwd}","{realname}","{phone}","1"); '
            try:
                cur.execute(sql2)
            except Exception as a:
                print(a)
            else:
                con.commit()
                print('注册成功')
                break

if __name__ == '__main__':
    con,cur = con_db()   # 连接数据库，返回数据库连接对象与游标对象
    # login(cur)
    username=input('yhum')
    passwd=input('passwd')
    realname=input('zsxm')
    phone=input('phone')
    regist(username, passwd, realname, phone)
# 注册  


#cording=utf-8
import threading,re

# def f(a,b):
#     print(a+b)
#
# f1=threading.Thread(target=f,args=(10,23))
# f2=threading.Thread(target=f,args=(20,34))
# f3=threading.Thread(target=f,args=(30,89))
# f1.start()
# f2.start()
# f3.start()
# print('hgj')


with open('untitled.html',encoding='utf-8') as a:
    s=a.read()
    s1=re.findall('a class="singleLink" (.+) title="" target="_blank">',s)
    s2=re.findall('<span class="text-links">(.+)</span>',s)
    a=dict(zip(s1[:-1],s2))
    print(a)




import random
import time

from POM.common import Dr_get
from POM.custom_page import Page_customer
from POM.login_test import Logintest


class   Customertest:
    def __init__(self):
        self.dr = Page_customer()
    def test_new(self):
        phone=random.randint(111111111,999999999)
        time.sleep(3)
        self.dr.link_customer().click()
        time.sleep(2)
        self.dr.input_phone().send_keys(str(phone))
        time.sleep(2)
        self.dr.buton_new().click()
        time.sleep(2)
        self.dr.close()

if __name__ == '__main__':
    Logintest().login()
    c=Customertest().test_new()


import pytest
import requests
from woniuticket.coomon.common import get_data, get_dic, request_t
def setup_function():
    r1=request_t('get','http://192.168.255.180:14200/cinema-stage/admin/login',{'username':'Wanda','password':'123456'})
    return r1

case=get_data(12)
@pytest.mark.parametrize('info',case['data'])
def test_main(info):
    if info[3]!='success':
        pytest.skip()
    else:
        data=get_dic(info[1])
        url=case['url']
        code=info[2]
        message=info[3]
        method=case['method']
        r=request_t(m=method,url=url,data=data)
        if code=='null':
            code=None
        if message=='null':
            message=None
        print(r.json())
        if code=='N/A':
            assert message in r.json()['message']
        elif message==None:
            assert code==r.json()['code']
        else:
            assert code == r.json()['code']
            assert message in r.json()['message']
def teardown_function():
    r1=request_t('delete','http://192.168.225.180:14200/cinema-stage/admin/logout')


if __name__ == '__main__':
    pytest.main(['-v',__file__])
    # case = get_data(12)
    # print(case)



import os
import time


from woniuticket.test_case import *
import pytest
base_path=os.path.dirname(__file__)
case_path=os.path.join(base_path,'test_case')
report_path=os.path.join(base_path,'report')
t=time.strftime('%Y%m%d-%H%M%S')
pytest.main(['-v',case_path])
# pytest.main(['-v','--alluredir=./report/',case_path])
# os.system('D:\\Programs\\allure-commandline-2.8.1\\allure-2.8.1\\bin\\allure.bat generate "D:\\python test\\woniuticket\\report"
# -o "D:\\python test\\woniuticket\\report\\alreport" ')



import os
import re

from lxml import etree
def pos(name):
    s=os.popen('adb shell uiautomator dump').read()
    print(s)
    path=s.strip().split(' ',-1)[-1]
    os.system(f'adb pull {path} D:\\report')
    a=etree.parse("D:\\report\window_dump.xml")
    b=a.xpath(f'//*[@text="{name}"]')[0]
    z=b.get('bounds')
    m=re.findall('\d{1,}',z)
    x=int((int(m[0])+int(m[2]))/2)
    y=int((int(m[1])+int(m[3]))/2)
    return x,y

def pos2(n):
    s = os.popen('adb shell uiautomator dump').read()
    # print(s)
    path = s.strip().split(' ', -1)[-1]
    os.system(f'adb pull {path} D:\\report')
    a = etree.parse("D:\\report\window_dump.xml")
    b = a.xpath(f'//*[@content-desc="{n}"]')[0]
    z = b.get('bounds')
    m = re.findall('\d{1,}', z)
    x = int((int(m[0]) + int(m[2])) / 2)
    y = int((int(m[1]) + int(m[3])) / 2)
    return x, y

if __name__ == '__main__':
    z=pos(7)
    print(z)
    z='afaf'





# !/usr/bin/python
# -*- coding: UTF-8 -*-
import smtplib
# 发送字符串的邮件
from email.mime.text import MIMEText
# 处理多种形态的邮件主体我们需要 MIMEMultipart 类
from email.mime.multipart import MIMEMultipart
# 处理图片需要 MIMEImage 类
from email.mime.image import MIMEImage

# 设置服务器所需信息
fromaddr = '1136865455@qq.com'  # 邮件发送方邮箱地址
password = 'brxhkuaoosefficj'  # 密码(部分邮箱为授权码)
toaddrs = ['3428192414@qq.com', '137xxxxx@qq.com']  # 邮件接受方邮箱地址，注意需要[]包裹，这意味着你可以写多个邮件地址群发

# 设置email信息
# ---------------------------发送字符串的邮件-----------------------------
# 邮件内容设置
message = MIMEText('hello,ziqiiii', 'plain', 'utf-8')
# 邮件主题
message['Subject'] = 'ziqiiii test email'
# 发送方信息
message['From'] = fromaddr
# 接受方信息
message['To'] =toaddrs[0]
# ---------------------------------------------------------------------


# 登录并发送邮件
try:
    server = smtplib.SMTP('smtp.qq.com',25)  # 163邮箱服务器地址，端口默认为25
    server.login(fromaddr, password)
    server.sendmail(fromaddr, toaddrs, message.as_string())
    print('success')
    server.quit()

except smtplib.SMTPException as e:
    print('error', e)  # 打印错误



import time

from appium import webdriver
class App():
    def __init__(self,deviceName,Version,udid,p):
        self.app1 = {
            "platformName": "Android",
            "appPackage": "com.miui.calculator",
            "appActivity": "com.miui.calculator.cal.CalculatorActivity",
            "noReset": "True"}
        self.app1["deviceName"]=deviceName
        self.app1["platformVersion"]=Version
        self.app1["udid"]=udid
        self.p=p
    def app(self):
        dr=webdriver.Remote(f'http://127.0.0.1:4723/wd/hub',self.app1)
        time.sleep(1)
        dr.find_element_by_id('com.miui.calculator:id/btn_9_s').click()
        dr.find_element_by_id('com.miui.calculator:id/btn_minus_s').click()
        dr.find_element_by_id('com.miui.calculator:id/btn_6_s').click()
        dr.find_element_by_id('com.miui.calculator:id/btn_equal_s').click()
        d=dr.find_elements_by_class_name('android.widget.TextView')[7]
        print(d.text)
        if int(d.text)==3:
            print('ok')
        else:
            print('fail')


if __name__ == '__main__':
    A=App('127.0.0.1:62025','7.1.2','127.0.0.1:62025')
    A.app()


import time,random
import xlsxwriter
class get_report:
    def __init__(self):
        #创建excel文件
        self.workbook = xlsxwriter.Workbook(f'D:\\python test\\test_book\\report\\report{random.randint(1,1000)}.xls')
        #在excel中创建工作表
        self.sheet_summary = self.workbook.add_worksheet('测试总况')

    #设置excel表格的列宽跟行高
    def set_sheet(self):
        #设置列的字母对应设置列宽
        self.sheet_summary.set_column("A:A",15)
        self.sheet_summary.set_column("B:E",20)
        #设置行高，第一行从0开始，这里从第二行开始开始设置
        self.sheet_summary.set_row(1,30)
        self.sheet_summary.set_row(2,30)
        self.sheet_summary.set_row(3,30)
        self.sheet_summary.set_row(4,30)
        self.sheet_summary.set_row(5,30)

    #设置表格的样式
    def set_format(self):
        #设置样式，这里设置两种样式style1 style2
        self.style1 = self.workbook.add_format({'bold':True,'font_size':18,'border':1})
        self.style2 = self.workbook.add_format({'bold':True,'font_size':14,'border':1})
        self.style1.set_align('vcenter')
        self.style2.set_align('vcenter')
        self.style1.set_align('center')
        self.style2.set_align('center')
        self.style1.set_bg_color("#70DB93")
        self.style1.set_color("#FFFFFF")

    #设置合并单元格以及插入表格内容
    def set_data(self,a,b,c,d):
        #合并单元格设置样式
        self.sheet_summary.merge_range('A1:E1','测试报告总概况',self.style1)
        self.sheet_summary.merge_range('A2:E2','测试概况',self.style2)
        self.sheet_summary.merge_range('A3:A6','项目图片',self.style2)
        #填写内容设置样式
        self.sheet_summary.write("B3","项目名称",self.style2)
        self.sheet_summary.write("B4","系统版本",self.style2)
        self.sheet_summary.write("B5","运行环境",self.style2)
        self.sheet_summary.write("B6","测试网络",self.style2)

        self.sheet_summary.write("C3","agileone",self.style2)
        self.sheet_summary.write("C4","V1.3",self.style2)
        self.sheet_summary.write("C5","windows 7",self.style2)
        self.sheet_summary.write("C6","外网",self.style2)

        self.sheet_summary.write("D3","用例总数",self.style2)
        self.sheet_summary.write("D4","通过总数",self.style2)
        self.sheet_summary.write("D5","失败总数",self.style2)
        self.sheet_summary.write("D6","测试日期",self.style2)

        self.sheet_summary.write("E3",a,self.style2)
        self.sheet_summary.write("E4",b,self.style2)
        self.sheet_summary.write("E5",c,self.style2)
        self.sheet_summary.write("E6",d,self.style2)

    #生成饼状图
    def set_pi(self):
        chart1 = self.workbook.add_chart({'type':'pie'})
        chart1.add_series({
            'name':'Agileone测试统计',
            'categories':'=测试总况!$D$4:$D$5',
            'values':'=测试总况!$E$4:$E$5',
        })
        chart1.set_title({'name':'Agileone测试统计'})
        # chart1.set_style(10)
        #指定插入报表的位置
        self.sheet_summary.insert_chart('A9',chart1)

    #生成柱状图
    def set_column(self):
        column_chart = self.workbook.add_chart({'type':'column'})
        column_chart.add_series({
            'name':'用例执行结果',
            'categories':'=测试总况!$D$4:$D$5',
            'values':'=测试总况!$E$4:$E$5',
        })
        column_chart.set_title({"name":"Agileone测试概况"})
        column_chart.set_y_axis({"name":"数量"})
        column_chart.set_x_axis({"name":"结果分类"})
        self.sheet_summary.insert_chart('A25',column_chart)

        self.workbook.close()
    def begin(self,a,b,c,d):
        self.set_sheet()
        self.set_format()
        self.set_data(a,b,c,d)
        self.set_pi()
        self.set_column()

if __name__=="__main__":
    d = get_report()
    print(time.strftime("%Y-%m-%d"))
    d.begin(5,3,2,time.strftime("%Y-%m-%d"))





import requests,mock,json
r='hello'
e='xllo'
n=len(e)
for i in range(len(r)):
    if r[i:i+n]==e:
        print(i)
    else:
        print(-1)

x={'data':[
    []
]}
url='http://hro.test-api.qqxb.jinsehuaqin.com:8800/public/model/w_site_tab_group/list'
head={'Content-Type':'application/json'}
pa={"name":"anonymous_site_list","item_index":0,"item_size":100,"prefilters":[],"columns":["*"],"order_obj":{},"filters":{"date_filters":[],"datetime_filters":[],"text_filters":[],"combo_text_filters":[],"date_between_filters":[],"number_filters":[],"search_filters":[],"boolean_filters":[],"enum_filters":[],"cascader_filters":[],"full_text_filters":[],"combine_full_text_filters":[],"tree_filters":[],"workflow_process_name_filters":[],"workflow_instance_state_filters":[],"simple_relationship_filters":[],"workflow_process_name_multi_filters":[]},"tagFilters":[],"sorts":[]}

pa=json.dumps(pa)
pa={'a':pa}
r=requests.get(url=url,params=pa,headers=head)
print(r.json())


def get_data(li):
    li.sort()
    n=0
    for i in li:
        n+=i
    return n/len(li),li[-1],li[0]


def get_res(res):
    head = str(res.headers)
    response = res.text
    x=len(head + response)

    return x


s=' ashjhsas asasak '
list=['1','2','3','4','5','6']
dc={1:'1',2:'2',3:'3',4:'4',5:'5'}
print(s.find('as'))
print(s.count('a'))
print(s.replace('a','我'))
print(s.split('a'))
print(s.capitalize())
print(s.title())
print(s.strip())
print(s.startswith(' '))
print(s.swapcase())
print(s.join(list))
list.append('7')
print(list)
list.insert(0,'0')
print(list)
list.remove('1')
print(list)
list.pop()
print(list)
print(max(list),min(list),list.count('2'),list.index('2'))
list.reverse()
print(list)
list.sort()
print(list)
print(dc.get(1),dc.keys(),dc.values())
for i in dc.items():
    print(i)
del dc[1]
print(dc)
dc.clear()
print(dc)
# reversed(list)
# print(list)
# del list
# print(list)


# coding=utf-8
'''
控制层
'''
import itertools
import random
import sys

from mud.services import page, regist, login, move, initmap, init_monster, init_player, checkhit, battle, postion, \
    get_item, save, load
from mud.view import display_main, display_regist, display_login, display_game, display_play, display_battle, \
    display_skill, display_get, display_gameover, display_adminlogin

pages=0
while True:
    # 显示主页
    if page=='main':
        display_main()
        pages=input('输入指令')
        if pages=='1':
            page='regist'
        if pages=='2':
            page='login'
        if pages=='3':
            sys.exit(0)
    elif page=='regist':
        display_regist()
        while True:
            name = input('输入用户名')
            passwd = input('输入密码')
            checkpasswd = input('确认密码')
            flag=regist(name, passwd, checkpasswd)
            if flag==True:
                page='login'
                break
    elif page=='login':
        display_login()
        name = input('输入用户名')
        passwd = input('输入密码')
        page=login(name, passwd)
    elif page=='adminlogin':
        display_adminlogin()
        name = input('输入用户名')
        passwd = input('输入密码')
        page = login(name, passwd)
    elif page=='game':
        display_game()
        pages = input('输入指令')
        map = (initmap())
        player = init_player(name)
        save('play.txt',player)
        if pages == '1':
            page = 'play'
            if page == 'play':
                monsters = init_monster()
                while True:
                    display_play()
                    position_=input('输入指令')
                    print(player['x,y'])
                    print(postion)
                    if position_=='5':
                        save('play.txt',player)
                    if position_=='6':
                        page='game'
                        break
                    player=move(player,position_)
                    # flag=checkhit(player)
                    # if flag==True:
                    #     display_battle()
                    # postion = random.sample(list(itertools.product(range(10), range(10))), 50)
                    # if player['x,y'] in postion:
                    flag=checkhit(player, postion)
                    if flag==True:
                        monster_name=monsters['name']
                        print(f'你遇到{monster_name}啦')
                        display_battle()
                        display_skill()
                        page=battle(player,monsters)
                        if page=='get_item':
                            display_get()
                            player=get_item(player,monsters)
                            print(player)
        elif pages == '2':
            for k,v in player.items():
                print(k,v)
        elif pages=='3':
            page = 'play'
            if page == 'play':
                monsters = init_monster()
                player=load('play.txt')
                while True:
                    display_play()
                    position_ = input('输入指令')
                    print(player['x,y'])
                    print(postion)
                    if position_ == '5':
                        save('play.txt',player)
                    if position_ == '6':
                        page = 'game'
                        break
                    player = move(player, position_)
                    # flag=checkhit(player)
                    # if flag==True:
                    #     display_battle()
                    # postion = random.sample(list(itertools.product(range(10), range(10))), 50)
                    # if player['x,y'] in postion:
                    flag = checkhit(player, postion)
                    if flag == True:
                        monster_name = monsters['name']
                        print(f'你遇到{monster_name}啦')
                        display_battle()
                        page = battle(player, monsters)
                        display_skill()
                        if page == 'get_item':
                            display_get()
                            player = get_item(player, monsters)
                            print(player)
        elif pages=='4':
            display_gameover()
            sys.exit(0)


import time,os
from pymouse import PyMouse
from pykeyboard import PyKeyboard

class Input_my:
    def __init__(self):
        self.m=PyMouse()
        self.k=PyKeyboard()
    def right_click(self,x,y):
        self.m.click(x,y,button=2)
    def light_click(self,x,y):
        self.m.click(x,y)
    def move(self,x,y):
        self.m.move(x,y)
    def input(self,str):
        self.k.type_string(str)
    def press(self,st):
        self.k.press_key(st)
        self.k.release_key(st)
    def nu_press(self,lis):
        self.k.processkey_key(lis)


if __name__ == '__main__':
    a=Input_my()
    time.sleep(5)
    a.move(762,355)
    a.light_click(762,355)



'''
POM，page object mode，实现页面元素与测试用例分离
封装页面基类，是所有页面类的基类，在类中封装页面操作常用方法
页面类，每一个页面封装一个类，在类中封装元素的定位以及元素的操作
'''
from selenium.webdriver.support.select import Select
import random
import time
class Base_Page:
    def __init__(self,driver):
        self.driver = driver
    def find_element(self,*args):
        '''定位一个元素'''
        return self.driver.find_element(*args)
    def find_elements(self,*args):
        '''定位一组元素'''
        return self.driver.find_elements(*args)
    def get_title(self):
        '''获取页面标题'''
        return self.driver.title
    def get_page(self):
        '''获取页面源码'''
        return self.driver.page_source
    def execute_js(self,js):
        '''执行js'''
        self.driver.execute_script(js)
    def accept_alert(self):
        '''在警告框中点击确定'''
        self.driver.switch_to.alert.accpet()
    def dismiss_alert(self):
        '''在警告框中点击取消'''
        self.driver.switch_to.alert.dismiss()
    def input_alert(self,msg):
        '''在警告框中点击取消'''
        self.driver.switch_to.alert.send_keys(msg)
    def frame_to(self,*args):
        '''切换到指定框架'''
        f = self.find_element(*args)   # 定位框架
        self.driver.switch_to.frame(f)  # 切换到框架
    def frame_outter(self):
        '''切换到外层框架'''
        self.driver.switch_to.default_content()
    def select_option(self,*args):
        '''随机选择下拉框选项'''
        s = self.find_element(*args)  # 定位下拉框
        option = len(Select(s).options)   # 获取选项数量
        Select(s).select_by_index(random.randint(0,option-1))  # 随机选择
    def input(self,msg,*args):
        '''输入内容'''
        ele = self.find_element(*args)  # 定位元素
        ele.clear()
        ele.send_keys(msg)
    def click(self,*args):
        '''点击还元素'''
        ele = self.find_element(*args)  # 定位元素
        ele.click()
    def get_img(self,file):
        '''截图'''
        self.driver.save_screenshot(file)
    def quit(self):
        '''关闭浏览器'''
        self.driver.quit()
    def close(self):
        '''关闭当前页面'''
        self.driver.close()
    def wait(self,t):
        '''隐式等待'''
        self.driver.implicitly_wait(t)
    def sleep(self,t):
        '''强制等待'''
        time.sleep(t)





#coding=utf-8
import requests,time,hashlib,base64
from Crypto.Cipher import AES
# url='http://127.0.0.1:4321/login'
# d={'account':'admin','passwd':'123456'}
# r=requests.post(url=url,data=d)
# c=dict(r.cookies)
# print(c)
# head={'Cookie':f'account={c["account"]}'}
# url='http://127.0.0.1:4321/query_borrow_info'
# r=requests.get(url,headers=head)
# print(r.json())
# url='http://47.92.203.151:8000/auth_get_event_list/'
# d={'eid':'1001'}
# user=('admin','sys123456')
# r=requests.get(url=url,params=d,auth=user)
# print(r.text)
# url='http://47.92.203.151:8000/token_login/'
# d={'username':'admin','password':'sys123456'}
# r=requests.post(url=url,data=d)
# token=r.json()['token']
# url='http://47.92.203.151:8000/api/token_get_event_list/'
# h={"Authorization":f"Token {token}"}
# r=requests.get(url=url,params={'eid':'1001'},headers=h)
# print(r.json())
# t=str(time.time()).split('.')[0]
# print(t)
# key='&Guest-Bugmaster'
# sign=hashlib.md5((t+key).encode('utf8')).hexdigest()
# print(sign)
# url='http://47.92.203.151:8000/sign_add_event/'
# d={'eid':'10001','time':t,'sign':sign}
# time.sleep(5)
# r=requests.post(url=url,data=d)
# print(r.json())
key='gsjhgasjhgajghgh'
iv=b"6736136712677667"
d='hdghgdhsgdhjgdgd'
aes=AES.new(key.encode('utf8'),AES.MODE_CBC,iv)
d=aes.encrypt(d.encode('utf8'))
print(d)
d=base64.urlsafe_b64encode(d)
print(d)
d1=base64.urlsafe_b64decode(d)
print(d)
aes1=AES.new(key.encode('utf8'),AES.MODE_CBC,iv)
d=aes1.decrypt(d1.decode('utf8'))
print(d)


'''
页面类，继承页面基类（Base_Page）封装与业务流程相关的元素定位以及元素操作方法
'''
from selenium.webdriver.common.by import By
from selenium import webdriver
from POM12.common.base_page import Base_Page
class Login_Page(Base_Page):
    # 定位器，列出元素的定位方法
    username = (By.ID,'username')   # 定位用户输入框
    passwd = (By.ID,'password')
    code = (By.ID,'verifycode')
    login_bt = (By.XPATH,'/html/body/div[4]/div/form/div[6]/button')  # 登录按钮
    # 输入用户名
    def input_username(self,name):
        self.input(name,*self.username)
    # 输入密码
    def input_paswd(self,pwd):
        self.input(pwd,*self.passwd)
    # 输入验证码
    def inout_code(self,cd):
        self.input(cd, *self.code)
    # 点击登录按钮
    def click_login(self):
        self.click(*self.login_bt)

if __name__ == '__main__':
    drive=webdriver.Chrome()
    drive.get('http://localhost:8080/woniusales/')
    log=Login_Page(drive)
    log.input_username('admin')
    log.input_paswd('123456')
    log.inout_code('0000')
    log.click_login()










from POM12.common.utils import *
import os,sys,threading
def run(brow):
    files = os.listdir(data_path)  # 获取data_path目录下所有测试用例文件的名称
    for i in files:
        n = str(i.split('.')[0])
        data = read_csv(os.path.join(data_path, i))[1:]
        x = 'test_woniusales.case.' + n
        __import__(x)
        m = sys.modules[x]
        r = getattr(m, n.title())
        obj = r(brow)
        for i in data:
            obj.test(i)
            time.sleep(2)
        obj.drive.quit()
def report(version,test_type):
    case_total, case_pass, case_fail, case_skip, rate=0, 0, 0, 0, 0
    case_date = 0  # 测试日期
    # 查询用例总数
    sql = f'select count(*) from report where type="{test_type}" and version="{version}" ;'
    case_total =cd1.query_one(sql)[0]
    # 查询通过用例总数
    sql=f'select count(*) from report where type="{test_type}" and version="{version}" and result = "success";'
    case_pass = cd1.query_one(sql)[0]
    # 查询失败用例总数
    sql=f'select count(*) from report where type="{test_type}" and version="{version}" and result = "fail";'
    case_fail = cd1.query_one(sql)[0]
    # 查询跳过用例总数
    case_skip= int(case_total)-int(case_pass)-int(case_fail)
    # 查询测试日期
    sql = f'select distinct runtime from report where type="{test_type}" and version="{version}";'
    case_date = str(cd1.query_one(sql)[0]).split()[0]
    # 通过率
    rate = f'{int(case_pass)*100/int(case_total):.2f}%'
    print(case_pass,case_fail,case_skip)
    with open(report_path + '/result_demo.html',encoding='utf8') as f:
        s = f.read()
        s = s.replace('&version', version)
        s = s.replace('&date', case_date)
        s = s.replace('&tester','zz')
        s = s.replace('&total',str(case_total))
        s = s.replace('&pass',str(case_pass))
        s = s.replace('&fail',str(case_fail))
        s = s.replace('&skip',str(case_skip))
        s = s.replace('&rate',str(rate))
    module_total, module_pass, module_fail, module_skip = 0, 0, 0, 0
    sql = f'''select module,count(*) from report 
                      where type="{test_type}" and version="{version}"
                      group by module;'''
    module_total = cd1.query_all(sql)
    # 查询每个模块通过的用例数
    sql = f'''select module,count(*) from report 
                              where type="{test_type}" and version="{version}" and result="success"
                              group by module;'''
    module_pass = cd1.query_all(sql)
    # 查询每个模块失败的用例数
    sql = f'''select module,count(*) from report 
                              where type="{test_type}" and version="{version}" and result="fail"
                              group by module;'''
    module_fail = cd1.query_all(sql)
    # 查询每个模块跳过的用例数
    sql = f'''select module,count(*) from report 
                              where type="{test_type}" and version="{version}" and result="skip"
                              group by module;'''
    module_skip = cd1.query_all(sql)
    detail = ''  # 保存每个模块用例信息
    print(module_total,module_pass,module_fail,module_skip)
    for i, j in enumerate(module_total):
        m, t, p, f, sk = 0, 0, 0, 0, 0  # 模块、用例数、通过数、失败数、跳过数
        print(i,j)
        m = j[0]  # 模块
        t = j[1]  # 用例数
        if not module_pass:
            pass
        elif j[0] in module_pass[i]:
            p = module_pass[i][1]
        if not module_fail:
            pass
        else:
            for n in module_fail:
                if m==n[0]:
                    f = module_fail[i][1]
        if not module_skip:
            pass
        elif j[0] in module_skip[i]:
            sk = module_skip[i][1]
        detail += f'''<tr>
    					<td class="bottom" width="180">{i+1}</td>
    					<td class="bottom">{m}</td>
    					<td class="bottom">{t}</td>
    					<td class="bottom">{p}</td>
    					<td class="bottom">
                            <a href="{m}12.html" style="color:red;">{f}</a>
                        </td>
    					<td class="bottom">{sk}</td>
    				    </tr>'''

    # 以读模式打开html格式的失败的测试用例模板
        with open(f'{report_path}/module_demo.html',encoding='utf8') as f1:
            page = f1.read()
            # 将每个模块的模块名对html模板中的&module进行替换
            page = page.replace('&module', m)
            # 将每个模块的用例数对html模板中的&total进行替换
            page = page.replace('&total',str(t))
            # 将每个模块的用例通过数对html模板中的&pass进行替换
            page = page.replace('&pass',str(p))
            # 将每个模块的用例失败数对html模板中的&fail进行替换
            page = page.replace('&fail', str(f))
            # 将每个模块的用例跳过数对html模板中的&skip进行替换
            page = page.replace('&skip', str(sk))
            # 查询每个模块失败的用例(返回元组形式)
            sql = f'select * from report where type="{test_type}" and version="{version}" and module="{m}" and result="fail";'
            cases = cd1.query_all(sql)
            print(cases)
            # 声明空字符串用以保存每个模块失败的用例信息
            case_detail = ''
            # 通过枚举的方式遍历每个模块失败用例信息(i用于保存元素的索引,j用于保存获取到的元素值)
            for i, j in enumerate(cases):
                # 将每个模块的失败用例信息整理成html标记语言
                case_detail += f'''
                            <tr>
                                <td class="bottom" >{i+1}</td>
                                <td class="case" >{j[2]}</td>
                                <td class="bottom">{j[1]}</td>
                                <td class="case" >{j[3]}</td>
                                <td class="bottom">{j[4]}</td>
                            </tr>
                            '''
                # 替换html失败的测试用例模板的table模块级内容
            page = page.replace('&detail', case_detail)
            # 以写模式创建以版本信息和测试日期为名称的html失败的测试用例报告
            with open(f'{report_path}/{m}12.html', 'w',encoding='utf8') as f:
                f.write(page)
            # 替换html测试报告的table模块级内容
        s = s.replace('&detail', detail)

        # 生成完整测试报告
        if not os.path.exists(f'{report_path}/{version}'):  # 判断目录是否存在
            os.system(f'mkdir {report_path}/{version}')  # 新建目录，目录名为版本号
        with open(f'{report_path}/{version}.html', 'w',encoding='utf8') as f:
            f.write(s)




# obj = None
# for i in files:
#     data = read_csv(os.path.join(data_path,i))[1:]
#     obj = eval('Test_' + data[0][1].capitalize() + '()')
#     # if 'login' in data[0][1]:
#     #     obj = Test_Login()
#     # elif 'add_customer' in data[0][1]:
#     #     obj = Test_Add_customer()
#     for i in data:
#         obj.test(i)
#         time.sleep(2)
if __name__ == '__main__':
    # th1=threading.Thread(target=run,args=('火狐',))
    # th2=threading.Thread(target=run,args=('谷歌',))
    # th1.start()
    # th2.start()
    # run('火狐')
    report('v1.0','ui')






# *_* coding:utf-8 *_*
from websocket import ABNF
import json,_thread,time,websocket

class Api_Websocket_Test:

    def __init__(self,netPort,netIp='14.215.128.97'):
        self.url = f'ws://{netIp}:{netPort}/'

    @staticmethod
    def wsMessage(ws,message):
       print(message)

    @staticmethod
    def wsError(ws,error):
        return error

    @staticmethod
    def wsClose(ws,msg='close connection'):
        return msg

    @staticmethod
    def parmas(data):
        def wsOpen(ws):
            def run(*args):
                #content = args
                for i in data:
                    ws.send(json.dumps(i))
                # step = 3200
                # with open(wav_path,'rb') as f:
                #     while True:
                #         read_data = f.read(step)
                #         if read_data:
                #             ws.send(read_data, ABNF.OPCODE_BINARY)
                #         if len(read_data) < step:
                #             break
                #         time.sleep(0.1)
                # ws.send('', ABNF.OPCODE_BINARY)
                time.sleep(1)
                ws.close()
            _thread.start_new_thread(run,())
        return wsOpen



if __name__ == "__main__":
    #websocket.enableTrace(True)
    sock = Api_Websocket_Test(netPort=29320)
    ws = websocket.WebSocketApp(sock.url,on_message=sock.wsMessage,on_error=sock.wsError,on_close=sock.wsClose)
    data = {"type": "getGps"}
    data2 = {"type": "getBitRate"}
    l=[data,data2]
    ws.on_open = sock.parmas(l)
    ws.run_forever()




import logging
import os

l=logging.getLogger()
l.setLevel(logging.INFO)
l_bath=os.path.join(os.path.dirname(__file__)+'/log/')
l_name=l_bath+'12.log'
f=logging.FileHandler(l_name,mode='a')
f.setLevel(logging.DEBUG)
formatter = logging.Formatter("%(asctime)s - %(filename)s[line:%(lineno)d] - %(levelname)s: %(message)s")
f.setFormatter(formatter)
l.addHandler(f)
l.debug('this is a logger debug message')
l.info('this is a logger info message')
l.warning('this is a logger warning message')
l.error('this is a logger error message')
l.critical('this is a logger critical message')



if __name__ == '__main__':
    print(l_bath)


import time

from app_ui.common.com import Com


class Test():
    def __init__(self):
        self.c=Com()
        self.dr=self.c.dr
    def test_login(self,phone,pwd,ex,res):
        # self.dr.find_element_by_id('com.modernsky.istv:id/txt_hot_city_item').click()
        time.sleep(1)
        self.dr.find_element_by_id('com.modernsky.istv:id/lin_view_me').click()
        time.sleep(1)
        self.dr.find_element_by_id('com.modernsky.istv:id/mChange').click()
        self.dr.find_element_by_id('com.modernsky.istv:id/mEditPhone').send_keys(phone)
        self.dr.find_element_by_id('com.modernsky.istv:id/mEditPwd').send_keys(pwd)
        self.dr.find_element_by_id('com.modernsky.istv:id/mLogin').click()
        time.sleep(1)
        if res=='success':
            self.dr.find_element_by_id('com.modernsky.istv:id/lin_view_me').click()
            time.sleep(1)
            t = self.dr.find_element_by_id('com.modernsky.istv:id/txt_bar_title').text
            if ex==t:
                print('ok')
            else:
                print('ko')
        else:
            t=self.dr.find_element_by_id('com.modernsky.istv:id/loginName').text
            if ex==t:
                print('ok')
            else:
                print('ko')


if __name__ == '__main__':

    li=[['15008477462','1136485op','个人中心','success'],['15008477462','1136485','密码登录','fail']]
    for i in li:
        z = Test()
        z.test_login(i[0],i[1],i[2],i[3])



import pymysql
class Con_DB:
    def __init__(self,user,password,db,host='localhost',port=3306,charset='utf8'):
        self.user = user
        self.password = password
        self.db = db
        self.host = host
        self.port = port
        self.charset = charset
        self.con = None
        self.cur = None
        self.con_db()
    def con_db(self):
        try:
            self.con = pymysql.connect(user=self.user,
                                      password=self.password,
                                      host=self.host,
                                      port=self.port,
                                      db=self.db,
                                      charset=self.charset)
        except Exception as e:
            print(e)
        else:
            self.cur = self.con.cursor()
    def query_all(self,sql):
        """查询返回多行数据"""
        try:
            self.cur.execute(sql)
            return self.cur.fetchall()
        except Exception as e:
            return str(e)
    def query_one(self,sql):
        """查询返回一行数据"""
        try:
            self.cur.execute(sql)
            return self.cur.fetchone()
        except Exception as e:
            return str(e)
    def dml(self,*sql):
        """DML操作"""
        try:
            for i in sql:
                self.cur.execute(i)
        except Exception as e:
            print(e)
            self.con.rollback()
        else:
            self.con.commit()
    def close(self):
        self.cur.close()
        self.con.close()
if __name__ == '__main__':
    cd = Con_DB('root','123456','test')
    account='admin'
    r = cd.query_all(f'select * from bookborinfo where account="{account}";')
    print(r)



    


import os
import re
import socket
import subprocess
import sys
import threading
import time

from app.asad import App


class Test:
    def __init__(self):
        self.l=[]
    def data(self):
        p=5000
        dp=6000
        de1=os.popen('adb devices').read()
        de2=re.findall('(.*?)	device',de1)
        de= de1.strip().split('\n')
        for i in de2:
            dic = {}
            devices=i.split('\t')[0]
            version = os.popen(f'adb -s {devices} shell getprop ro.build.version.release').read().strip()
            p=self.check_p(p)
            dp=self.check_p(dp)
            dic['udid']=devices
            dic['p']=p
            dic['dp']=dp
            dic['version']=version
            self.l.append(dic)
            p += 1
            dp += 1
        return self.l
    def check_p(self,p):
        while True:
            if self.de(p):
                p+=1
            else:
                return p
                break
    def de(self,p):
        con = socket.socket()
        try:
            con.connect(('127.0.0.1',p))
            return True
            con.shutdown(2)
        except:
            return False

    def run(self,p,bp,udid,version):
        # t=subprocess.run(f'start /b appium -a 127.0.0.1 -p {p} -bp {bp} -U {udid} --platform-version {version}',shell=True,stdout=subprocess.PIPE,stderr=subprocess.PIPE,encoding="utf-8")
        # print(t.stderr)
        # sys.path.append("/path/to/C:/Users/树先生/AppData/Roaming/npm/appium.cmd")
        # os.system(f'move C:/Users/树先生/AppData/Roaming/npm && start /b appium -a 127.0.0.1 -p {p} -bp {bp} -U {udid} --platform-version {version}')
        subprocess.Popen(f'start /b C:/Users/树先生/AppData/Roaming/npm/appium.cmd -a 127.0.0.1 -p {p} -bp {bp} -U {udid} --platform-version {version}',shell=True)
        time.sleep(4)
        App(udid,version,udid,p).app()
    def run_mokey(self,udid,package):
        u=udid.split(':')[1]
        log_path=time.strftime(f'{u}-%H%M%S.txt')
        print(log_path)
        os.system(f'adb -s {udid} shell monkey -p {package} -v -v --throttle 50 1000 > D:\\{log_path}')
        time.sleep(8)
        with open(f'D:\\{log_path}') as f:
            result=f.read()
        if 'anr' in result or 'ANR' in result:
            print(f'此次{package}应用在{udid}移动设备上执行monkey测试时出现了无响应，响应超时异常!')
        else:
            print(f'此次{package}应用在{udid}移动设备上执行monkey测试时未出现无响应，响应超时异常.')
        if 'crash' in result or 'CRASH' in result:
            print(f'此次{package}应用在{udid}移动设备上执行monkey测试时出现了崩溃，闪退异常!')
        else:
            print(f'此次{package}应用在{udid}移动设备上执行monkey测试时未出现崩溃，闪退异常.')
        if 'error' in result or 'EXCEPTION' in result:
            print(f'此次{package}应用在{udid}移动设备上执行monkey测试时出现了未知异常!')
        if 'Monkey finished' in result:
            print(f'此次{package}应用在{udid}移动设备上执行monkey测试时未出现任何异常.')


if __name__ == '__main__':
    l=input('输入测试类型')
    if l=='appium':
        os.system('taskkill /f /im node.exe')
        t=Test()
        l=[]
        for i in t.data():
            th=threading.Thread(target=t.run,args=(int(i['p']),int(i['dp']),i['udid'],i['version']))
            th.start()
        th.join()
    else:
        t=Test()
        l = []
        for i in t.data():
            th=threading.Thread(target=t.run_mokey,args=(i['udid'],'com.miui.calculator'))
            l.append(th)
        for t in l:
            t.start()
        t.join()




#coding=utf8
import time
class Demo:
    @classmethod
    def goto(cls,dr,url):
        dr.get(url)
    @classmethod
    def input(cls, dr,obj,value):
        ob=obj.split('=',1)
        m=eval('dr.find_element_by_'+ob[0]+f'("{ob[1]}")')
        m.clear()
        m.send_keys(value)
        # if obj.startswith('id')==True:
        #     m=dr.find_element_by_id(obj[3:])
        #     m.clear()
        #     m.send_keys(value)
        # if obj.startswith('xpath')==True:
        #     m=dr.find_element_by_xpath(obj[6:])
        #     m.clear()
        #     m.send_keys(value)

    @classmethod
    def delay(cls,dr,li):
        time.sleep(int(li))

    @classmethod
    def singleclick(cls, dr, obj):
        # if obj.startswith('id') == True:
        #     m = dr.find_element_by_id(obj[3:])
        #     m.click()
        #
        # if obj.startswith('xpath') == True:
        #     m = dr.find_element_by_xpath(obj[6:])
        #     m.click()
        ob = obj.split('=', 1)
        m = eval('dr.find_element_by_' + ob[0] + f'("{ob[1]}")')
        m.click()






#coding=utf8
from selenium import webdriver
import time
from KDT.case import Demo
from KDT.data import dataread

dr=webdriver.Chrome()
# dr.get('http://www.baidu.com')
dr.maximize_window()
l=dataread()
# print(l)
for i in l:
    li=i.strip().split(',')
    # print(li)
    d=Demo()
    args=li[1:]
    m=getattr(Demo,li[0])
    m(dr,*args)


# coding=utf-8
'''
界面层
'''

#主页
def display_main():
    print('-' * 100)
    print('\t', '1.注册游戏'.ljust(20,'*'), '2.登录游戏'.center(30,'*'), '3.退出'.rjust(20,'*'))
    print('-' * 100)
#注册页面
def display_regist():
    print('-'*100)
    print('\t','注册账户'.center(80,'*'))
    print('\t', '输入用户名'.ljust(20,'*'),'输入密码'.center(30,'*'),'确认密码'.rjust(20,'*'))
    print('-'*100)
#登录页面
def display_login():
    print('-'*100)
    print('\t','登录账户'.center(80,'*'))
    print('-'*100)
#管理员登录界面
def display_adminlogin():
    print('-' * 100)
    print('\t', '管理员登录账户'.center(80, '*'))
    print('-' * 100)
#会员管理
def display_users():
    print('-' * 100)
    print('\t', '1.会员管理'.ljust(40, '*'),'2.playgame'.rjust(40,'*'))
    print('-' * 100)
#角色选择
def display_play():
    print('-'*100)
    print('\t','移动角色'.center(95,'*'))
    print('\t', '1.按w向上移动'.ljust(20,'*'),'2.按s向下移动'.center(20,'*'),'3.按a向左移动'.center(20,'*'),'4.按d向右移动'.rjust(20,'*'))
    print('\t', '5.存档'.ljust(45,'*'),'6.退出'.center(45, '*'))
    print('-'*100)
#游戏界面
def display_game():
    print('-'*100)
    print('\t','欢迎来到洛圣都'.center(90,'*'))
    print('\t', '1.开始游戏'.ljust(20,'*'),'2.显示角色'.center(20,'*'),'3.继续游戏'.center(20,'*'),'4.退出'.rjust(20,'*'))
    print('-'*100)
#遇敌界面
def display_checkhit():
    print('-'*100)
    print('\t','遇到怪物啦'.center(80,'*'))
    print('-'*100)
#战斗界面
def display_battle():
    print('-'*100)
    print('\t','batlle start'.center(80,'*'))
    print('-'*100)
#技能使用界面
def display_skill():
    print('-'*100)
    print('\t','1.普通攻击'.ljust(20,'*'),'2.农夫三拳'.center(20,'*'),'3.欧拉欧拉'.center(20,'*'),'4.砸哇唔多'.rjust(20,'*'))
    print('-'*100)
#拾取界面
def display_get():
    print('-'*100)
    print('\t','装备拾取'.center(80,'*'))
    print('-'*100)
#游戏结束界面
def display_gameover():
    print('-'*100)
    print('\t','game over'.center(80,'*'))
    print('-'*100)


import os
import random
import time


from pymouse import PyMouse
from pykeyboard import PyKeyboard
from selenium import webdriver

from My_usee.hghh import Img_mai


class Test_woniusales:
    def __init__(self):
        self.mymouse=PyMouse()
        self.mykeyboard=PyKeyboard()
        self.match=Img_mai()
    #点击
    def click(self,img_name):
        x,y=self.match.return_pos(img_name)
        self.mymouse.click(x,y)
    #清空输入值
    def clear_input(self):
        self.mykeyboard.press_keys([self.mykeyboard.control_key,"a"])
        time.sleep(0.5)
        self.mykeyboard.tap_key(self.mykeyboard.backspace_key)
    #下拉框操作
    def  select_test(self,num):
        for i in range(num):
            self.mykeyboard.tap_key(self.mykeyboard.down_key)
        self.mykeyboard.tap_key(self.mykeyboard.enter_key)
    #打开浏览器进入测试界面
    def input_keys(self,str):
        self.mykeyboard.type_string(str)
    def key(self,s):
        self.mykeyboard.press_key(s)
        self.mykeyboard.release_key(s)
    def unkey(self,li):
        self.mykeyboard.press_keys(li)
    def open_browser(self,url):
        u=webdriver.Chrome()
        u.get(url)
        u.maximize_window()
        # os.system(f'start /b \"C:\Program Files\Google\Chrome\Application\chrome.exe" {url}')
    def main_test(self):
        self.open_browser("http://localhost:8080/woniusales/")
        time.sleep(3)
        self.key(self.mykeyboard.shift_r_key)
        time.sleep(2)
        self.click("user.jpg")
        # self.key(self.mykeyboard.backspace_key)
        # self.input_keys("admin")
        # self.key(self.mykeyboard.backspace_key)
        # self.key(self.mykeyboard.backspace_key)
        self.unkey([self.mykeyboard.control_l_key,'v'])
        time.sleep(1)
        self.click("password.jpg")
        self.input_keys("123456")
        time.sleep(1)
        self.click("ver.jpg")
        self.input_keys("0000")
        time.sleep(1)
        self.click('login.jpg')
        time.sleep(2)
        self.click('customer.jpg')
        time.sleep(2)
        self.click("phone.jpg")
        num=random.randint(1111111111,9999999999)
        self.input_keys(str(num))
        time.sleep(2)
        self.click("add.jpg")
        time.sleep(2)
if __name__ == '__main__':
    t=Test_woniusales().main_test()




import pytest
# 使用pytest完成login、add_user、delete_user功能的测试
# add_user、delete_user功能需要登录后才能使用

def login(name='admin',passwd='123456'):
    if name == 'admin' and passwd == '123456':
        return 'success'
    else:
        return 'account or password error'

def add_user(id,name,pwd):
    if id not in ('1001','1002', '1003', '1004'):  # 判断id是否存在
        if name not in ('admin','admin1','admin2','admin3'):  # 判断用户名是否存在
            return 'add user success'
        return 'name already exists'
    else:
        return 'id already exists'

def delete_user(id):
    if id in ('1001','1002', '1003', '1004'):   # 判断id是否存在
        if id == '1001':    # 判断id是否为管理员
            return 'administrator cannot be deleted'
        else:
            return 'delete success'
    return 'id does not exists'
# def setup_function():
#     login('admin','12345q6')
#     print('测试开始')
# def teardown_function():
#     print('测试完成')
infos=[('1005','admin5','215361','pass'),('1004','admin5','215361','filed'),('1005','admin3','215361','filed'),('1002','admin2','215361','filed')]
@pytest.mark.parametrize('info',infos)
def test_1(q12,info):
    id,name,pwd,ex=info[0],info[1],info[2],info[3]
    a=add_user(id,name,pwd)
    if ex=='pass':
        assert 'success' in a
    else:
        assert  'exists' in a

infos1=[('1003','pass'),('1001','filed'),('1005','filed')]
@pytest.mark.parametrize('info',infos1)
def test_2(q12,info):
    id,ex=info[0],info[1]
    a=delete_user(id)
    if ex=='pass':
        assert 'success' in a
    else:
        assert  'not' in a


if __name__ == '__main__':
    pytest.main(['-s','./'])
    # pytest.main(['-v','-k k','test1.py'])



import cv2
from PIL import ImageGrab
import os
class Img_mai:
    def __init__(self):
        self.path=os.path.abspath('.\\imgs')
    def return_pos(self,name):
        ImageGrab.grab().save(self.path+'\\big.jpg')
        # print(self.path+'/big.png')
        s=cv2.imread(self.path+f'\\{name}')
        b=cv2.imread(self.path+'\\big.jpg')
        result=cv2.matchTemplate(b,s,cv2.TM_CCOEFF_NORMED)
        # print(result)
        pos=cv2.minMaxLoc(result)
        # print(pos)
        x=pos[3][0] + int(s.shape[1]/2)
        y=pos[3][1] + int(s.shape[0]/2)
        if pos[1]>0.8:
            # print(x,y)
            return x,y
        else:
            return -1,-1
if __name__ == '__main__':
    t=Img_mai()
    x,y=t.return_pos('user.png')
    print(x,y)




import setuptools


setuptools.setup(
    name='san_make',
    version='1.0.1',
    author='',
    description='',
    long_description_content_type='text/markdown',
    url='https://github.com/',
    packages=setuptools.find_packages(),
    classfile=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],

)


import random,time
class Utils:
    def is_continue(self):
        mark = input('继续输入请按1，结束请按任意键：')
        if mark == '1':
            return True
        return False
    def get_time(self):
        return time.strftime('%Y-%m-%d %X')



#coding=utf8
def dataread():
    with open('D:\python test\KDT\data.txt',encoding='utf8') as f:
        li=f.readlines()
        lii=[]
    for i in li:
        if not i.startswith('#')==True:
            # li.remove(i)
            lii.append(i)
    return lii


if __name__ == '__main__':
    i=dataread()
    i.remove('singleclick,id=su\n')
    print(i)




import time,pytest
def time_1(func):
    print(func)
    def inner(*args,**kwargs):
        print(**kwargs)
        start=time.time()
        r=func(*args,**kwargs)
        end=time.time()
        print(end-start)
        return r
    return inner

@time_1
def f1(a):
    s=0
    for i in range(1,a+1):
        s+=i
    print(s)



if __name__ == '__main__':
    s1=f1(1000000)
    s2=f1(9999999)


#cording=utf-8
import xlrd,csv,pymysql
#
# book=xlrd.open_workbook('data.xls')
# sheet=book.sheet_names()
# print(sheet)
# sheet1=book.sheets()
# print(sheet1)
# b=book.sheet_by_name('sheet1')
# print(b)
# a=book.sheet_by_index(0)
# print(a)
# row=b.nrows
# print(row)
# for i in range(row):
#     n=a.row_types(i)
#     print(n)
# print(b.cell_value(1,1))
# col=b.ncols
# for i in range(row):
#     for j in range(col):
#         m=b.cell_value(i,j)
#         print(m)
# with open('as.csv',encoding='utf-8') as f:
#     r=csv.reader(f)
#     print(r)
#     for i in r:
#         print(i)

con=pymysql.connect(host='localhost',user='root',passwd='123456',port=3306,db='test',charset='utf8')
print(con)
cur=con.cursor()
sql='select * from userinfo;'
cur.execute(sql)
a=cur.fetchone()
print(a)
a=cur.fetchall()
print(a)
cur.close()
con.close()


import sys

from dteacher.con_db import Con_DB
from dteacher.utils import Utils
import time
class App:
    def __init__(self,con_db,utils):
        self.con_db = con_db      # 数据库操作类的对象
        self.utils = utils
        self.welcome()
    def login(self):
        # 接收外部输入的账号和密码
        print('-------------- 登录 ---------------')
        flag_1, flag_2 = True, True  # 控制内层和外层循环
        error = 0  # 计数器，保存密码连续错误次数
        while flag_1:
            account = input('账 号：')
            sql = f'select * from userinfo where account="{account}";'
            userinfo = self.con_db.query_one(sql)   # 查询指定用户的信息
            if userinfo:  # 判断账号是否存在
                while flag_2:
                    passwd = input('密 码：')
                    if passwd == userinfo[2]:  # 判断密码是否正确
                        print('登录成功')
                        if userinfo[-1] == '1':
                            a=Administrator(userinfo,self.con_db,utils)
                            a.main()
                        else:
                            Ordinary(userinfo,self.con_db,utils).main()
                    else:
                        error += 1
                        if error == 3:
                            print('密码已连续错误3次，程序结束')
                            flag_1, flag_2 = False, False
                        else:
                            print('密码错误，请重新输入')
                            flag_2 = self.utils.is_continue()
                            flag_1 = flag_2
            else:
                print('账号不存在')
                flag_1 = self.utils.is_continue()
    def reg(self):
        print('-------------- 注册 ---------------')
        flag_1, flag_2 = True, True  # 控制内层和外层循环
        while flag_1:
            account = input('账 号：')
            sql = f'select * from userinfo where account="{account}";'
            userinfo = self.con_db.query_one(sql)   # 查询指定用户的信息
            if not userinfo:
                passwd = input('密 码：')  # 长度6-10位，字母、数字、下划线组成
                realname = input('姓 名：')
                phone = input('手机号：')  # 纯数字、11位、1开头、（3，5，7，8）
                sql = f'''insert into userinfo(`account`,`passwd`,`realname`,`phone`,`role`)
                         values("{account}","{passwd}","{realname}","{phone}","0");
                      '''
                self.con_db.dml(sql)
                print('注册成功')
                flag_1 = False
            else:
                print('账号已存在，请重新输入')
                flag_1 = self.utils.is_continue()
    def welcome(self):
        print('------ 欢迎使用蜗牛图书管理系统 -------')
        print('------ 1 登录  2 注册  3 退出 -------')
        s = input('请选择服务：')
        if s == '1':
            self.login()
        elif s == '2':
            self.reg()
        else:
            self.con_db.close()
            sys.exit('再见！！！！！')
class Ordinary:
    """非管理员"""
    def __init__(self,userinfo,con_db,utils):
        self.userinfo = userinfo      # 当前登录用户信息
        self.con_db = con_db     # 数据库连接对象
        self.utils=utils
        # self.main()
    def main(self):
        while True:
            print('------------ 请选择服务 ------------')
            print('             1 借阅信息             ')
            print('             2 图书查询             ')
            print('             3 借阅图书             ')
            print('             4 归还图书             ')
            print('             5 退   出              ')
            s = input('服务：')
            if s == '1':
                self.query_borrow_info()
            elif s == '2':
                self.query_book_info()
            elif s == '3':
                self.borrow_book()
            elif s == '4':
                self.return_book()
            else:
                exit()

    def query_borrow_info(self):
        """查询借阅信息"""
        sql = f'''select bi.account,bi.bookid,b.name,bi.bro_date,bi.return_date from bookinfo bi,book b
                  where bi.account="{self.userinfo[1]}" and bi.bookid=b.bookid;'''
        r = self.con_db.query_all(sql)
        print(f'{"序号":4}\t{"编号":4}\t{"书名":12}\t{"借阅日期":8}\t状态')
        for i,j in enumerate(r):
            print(f'{i+1:^4}\t{j[1]:4}\t{j[2]:12}\t{str(j[3]).split()[0]}\t{"已归还" if j[-1] else "未归还"}')
    def query_book_info(self):
        '''图书查询（支持编号、书名的模糊查询）'''
        a=input('请输入查询信息')
        sql = f'''select * from book where bookid="{a}"or name like "%{a}%";'''
        r = self.con_db.query_all(sql)
        print(r)
        return r
    def borrow_book(self):
        '''借阅'''
        while True:
            a=input('请选择要借用的图书id')
            c=int(input('请选择借阅数量'))
            sql=f'select count from book where bookid ="{a}";'
            r=self.con_db.query_one(sql)
            b=int(r[0])
            if b>=c:
                m=b-c
                sql1=f'''update book set count= "{m}" where bookid="{a}";'''
                sql2=f'''insert into bookinfo (`account`,`bookid`,`bro_date`)values("{self.userinfo[1]}","{a}","{self.utils.get_time()}");'''
                self.con_db.dml(sql1,sql2)
                break
            else:
                d=input('图书数量不够，重选数量按1，不借按2')
                if d=='1':
                    continue
                else:
                    break

    def return_book(self):
        a=input('请输入要归还的图书id')
        b=input('请输入要归还的图书数量')
        sql = f'''update book set count=(count+"{b}") where bookid="{a}";'''
        #t = time.strftime('%Y-%m-%d %X')
        self.con_db.dml(sql)
        sql = f'''update bookinfo set return_date="{self.utils.get_time()}" where bookid="{a}";'''
        self.con_db.dml(sql)



class Administrator(Ordinary):
    """管理员类，继承非管理员类"""
    def main(self):
        """重写父类方法"""
        while True:
            print('------ 请 选 择 服 务 ------')
            print('         1 借阅信息         ')
            print('         2 图书查询         ')
            print('         3 借阅图书         ')
            print('         4 归还图书         ')
            print('         5 添加图书         ')
            print('         6 删除图书         ')
            print('         7 退    出         ')
            s = input('服务：')
            if s == '1':
                self.query_borrow_info()
            elif s == '2':
                self.query_book_info()
            elif s == '3':
                self.borrow_book()
            elif s == '4':
                self.return_book()
            elif s == '5':
                self.add_book()
            elif s == '6':
                self.delete_book()
            else:
                sys.exit(0)

    def add_book(self):
        flag=True
        while flag:
            a = input('请选择编号')
            b=input('请选择要添加的图书名')
            c = input('请选择作者名')
            d=input('请选择想要添加的图书数量')
            sql=f'select * from book where bookid="{a}" and name="{b}" and author="{c}";'
            r=self.con_db.query_one(sql)
            if bool(r):
                sql=f'update book set count=(count+"{int(d)}") where bookid ="{a}";'
                self.con_db.dml(sql)
                print('添加成功')
            else:
                sql=f'select * from book where bookid="{a}";'
                r = self.con_db.query_one(sql)
                if bool(r):
                    print('编号已存在')
                else:
                    sql = f'select * from book where name="{b}" and author="{c}";'
                    r = self.con_db.query_one(sql)
                    if bool(r):
                        print(f'{b}已存在')
                    else:
                        sql = f'insert into book (`bookid`,`name`,`author`,`count`)values ("{a}","{b}","{c}","{d}");'
                        self.con_db.dml(sql)
                        print('添加成功')
                        break
            flag = self.utils.is_continue()

    def delete_book(self):
        while True:
            a=input('请选择想要删除的图书')
            sql=f'select * from book where name="{a}";'
            r=self.con_db.query_one(sql)
            if bool(r):
                sql=f'delete from book where name = "{a}";'
                self.con_db.dml(sql)
                print('删除成功')
                break
            else:
                print('图书不存在')
if __name__ == '__main__':
    cd = Con_DB('root','123456','test')
    utils = Utils()
    app = App(cd,utils)






import os

from lxml import etree
def pos(name):
    s=os.popen('adb shell uiautomator dump').read()
    print(s)
    path=s.strip().split(' ',-1)[-1]
    os.system(f'adb pull {path} D:\\report')
    a=etree.parse("D:\\report\window_dump.xml")
    b=a.xpath(f'//*[@text="{name}"]')[0]
    z=b.get('bounds')
    z.replace('[','')
    return z


if __name__ == '__main__':
    z=pos(7)
    print(z)




from flask import Flask,jsonify,request,render_template,make_response
from homework.con_db import Con_DB
a=Flask(__name__)
@a.route('/st1',methods=['GET','POST'])
def login():
    if request.method=='GET':
        return jsonify({'code':'1003','jieguo':'filed'})
    else:
        name=request.form.get('name')
        passwd=request.values.get('passwd')
        if name == 'admin' and passwd == '123456':
            res=make_response(jsonify({'code':'10001','jieguo':'success'}))
            res.set_cookie('username',name,max_age=60)
            return res
        else:
            return jsonify({'code':'1001','jieguo':'filed'})
@a.route('/st',methods=['GET'])
def index1():
    return render_template('login.html')
if __name__ == '__main__':
    a.run(host='0.0.0.0',port=4321,debug=True)


import time

import websocket,json

url='ws://14.215.128.97:29316/'
ws=websocket.WebSocket()
ws.connect(url)
data={"type":"getGps"}
data2={"type":"getBitRate"}
data=json.dumps(data)
data2=json.dumps(data2)
ws.send(data)
time.sleep(1)
rev=ws.recv()
print(rev)
ws.send(data2)
time.sleep(1)
rev=ws.recv()
print(rev)
ws.close()

